Merge master into staging-next

This commit is contained in:
nixpkgs-ci[bot]
2025-05-16 18:05:48 +00:00
committed by GitHub
105 changed files with 6495 additions and 573 deletions
+2 -1
View File
@@ -25,8 +25,9 @@ For new packages please briefly describe the package or provide a link to its ho
- made sure NixOS tests are [linked](https://github.com/NixOS/nixpkgs/blob/master/pkgs/README.md#linking-nixos-module-tests-to-a-package) to the relevant packages
- [ ] Tested compilation of all packages that depend on this change using `nix-shell -p nixpkgs-review --run "nixpkgs-review rev HEAD"`. Note: all changes have to be committed, also see [nixpkgs-review usage](https://github.com/Mic92/nixpkgs-review#usage)
- [ ] Tested basic functionality of all binary files (usually in `./result/bin/`)
- [25.05 Release Notes](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2505.section.md) (or backporting [24.11](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2411.section.md) and [25.05](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2505.section.md) Release notes)
- [Nixpkgs 25.11 Release Notes](https://github.com/NixOS/nixpkgs/blob/master/doc/release-notes/rl-2511.section.md) (or backporting [24.11](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/release-notes/rl-2411.section.md) and [25.05](https://github.com/NixOS/nixpkgs/blob/master/doc/manual/release-notes/rl-2505.section.md) Nixpkgs Release notes)
- [ ] (Package updates) Added a release notes entry if the change is major or breaking
- [NixOS 25.11 Release Notes](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2511.section.md) (or backporting [24.11](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2411.section.md) and [25.05](https://github.com/NixOS/nixpkgs/blob/master/nixos/doc/manual/release-notes/rl-2505.section.md) NixOS Release notes)
- [ ] (Module updates) Added a release notes entry if the change is significant
- [ ] (Module addition) Added a release notes entry if adding a new NixOS module
- [ ] Fits [CONTRIBUTING.md](https://github.com/NixOS/nixpkgs/blob/master/CONTRIBUTING.md).
+1 -1
View File
@@ -31,7 +31,7 @@ jobs:
into: staging-next-24.11
- from: staging-next-24.11
into: staging-24.11
- from: master
- from: release-25.05
into: staging-next-25.05
- from: staging-next-25.05
into: staging-25.05
+1 -1
View File
@@ -345,7 +345,7 @@ See [Nix Channel Status](https://status.nixos.org/) for the current channels and
Here's a brief overview of the main Git branches and what channels they're used for:
- `master`: The main branch, used for the unstable channels such as `nixpkgs-unstable`, `nixos-unstable` and `nixos-unstable-small`.
- `release-YY.MM` (e.g. `release-25.05`): The NixOS release branches, used for the stable channels such as `nixos-25.05`, `nixos-25.05-small` and `nixpkgs-25.05-darwin`.
- `release-YY.MM` (e.g. `release-25.11`): The NixOS release branches, used for the stable channels such as `nixos-25.11`, `nixos-25.11-small` and `nixpkgs-25.11-darwin`.
When a channel is updated, a corresponding Git branch is also updated to point to the corresponding commit.
So e.g. the [`nixpkgs-unstable` branch](https://github.com/nixos/nixpkgs/tree/nixpkgs-unstable) corresponds to the Git commit from the [`nixpkgs-unstable` channel](https://channels.nixos.org/nixpkgs-unstable).
+13 -10
View File
@@ -35,18 +35,21 @@ rustPlatform.buildRustPackage (finalAttrs: {
hash = "...";
};
nativeBuildInputs = [
# Pull in our main hook
cargo-tauri.hook
nativeBuildInputs =
[
# Pull in our main hook
cargo-tauri.hook
# Setup npm
nodejs
npmHooks.npmConfigHook
# Setup npm
nodejs
npmHooks.npmConfigHook
# Make sure we can find our libraries
pkg-config
wrapGAppsHook4
];
# Make sure we can find our libraries
pkg-config
]
++ lib.optionals stdenv.hostPlatform.isLinux [
wrapGAppsHook4
];
buildInputs =
[ openssl ]
+1
View File
@@ -3,5 +3,6 @@
This section lists the release notes for each stable version of Nixpkgs and current unstable revision.
```{=include=} sections
rl-2511.section.md
rl-2505.section.md
```
+1 -1
View File
@@ -1,4 +1,4 @@
# Nixpkgs 25.11 (2025.11/??) {#sec-nixpkgs-release-25.11}
# Nixpkgs 25.11 ("Xantusia", 2025.11/??) {#sec-nixpkgs-release-25.11}
## Highlights {#sec-nixpkgs-release-25.11-highlights}
<!-- To avoid merge conflicts, consider adding your item at an arbitrary place in the list instead. -->
+1 -1
View File
@@ -1 +1 @@
25.05
25.11
+1 -1
View File
@@ -439,7 +439,7 @@ in
On each release the first letter is bumped and a new animal is chosen
starting with that new letter.
*/
codeName = "Warbler";
codeName = "Xantusia";
/**
Returns the current nixpkgs version suffix as string.
+25 -6
View File
@@ -4811,6 +4811,12 @@
name = "Coca";
keys = [ { fingerprint = "99CB 86FF 62BB 7DA4 8903 B16D 0328 2DF8 8179 AB19"; } ];
};
cococolanosugar = {
name = "George Xu";
github = "cococolanosugar";
githubId = 1736138;
email = "cococolanosugar@gmail.com";
};
coconnor = {
email = "coreyoconnor@gmail.com";
github = "coreyoconnor";
@@ -7292,6 +7298,13 @@
githubId = 428026;
name = "embr";
};
emilia = {
email = "nix@emilia.codes";
github = "emiliaaah";
githubId = 55017867;
name = "Emilia";
keys = [ { fingerprint = "F772 3569 4B43 B599 73C2 A931 1EFB E941 B89B B810"; } ];
};
emilioziniades = {
email = "emilioziniades@protonmail.com";
github = "emilioziniades";
@@ -9182,6 +9195,12 @@
githubId = 1621335;
name = "Andrew Trachenko";
};
goodylove = {
github = "goodylove";
email = "goodyc474@gmail.com";
githubId = 104577296;
name = "Nwachukwu Goodness";
};
gordon-bp = {
email = "gordy@hanakano.com";
github = "Gordon-BP";
@@ -17753,6 +17772,12 @@
githubId = 41154684;
name = "nokazn";
};
nomaterials = {
email = "nomaterials@gmail.com";
github = "no-materials";
githubId = 16938952;
name = "nomaterials";
};
nomeata = {
email = "mail@joachim-breitner.de";
github = "nomeata";
@@ -27290,12 +27315,6 @@
githubId = 5986078;
name = "Zunway Liang";
};
zanculmarktum = {
name = "Azure Zanculmarktum";
email = "zanculmarktum@gmail.com";
github = "zanculmarktum";
githubId = 16958511;
};
zane = {
name = "Zane van Iperen";
email = "zane@zanevaniperen.com";
+11 -2
View File
@@ -869,6 +869,7 @@ with lib.maintainers;
qyriad
_9999years
lf-
alois31
];
scope = "Maintain the Lix package manager inside of Nixpkgs.";
shortName = "Lix ecosystem";
@@ -1119,9 +1120,17 @@ with lib.maintainers;
};
sdl = {
members = [ ];
scope = "Maintain SDL libraries.";
members = [
evythedemon
grimmauld
jansol
marcin-serwin
pbsds
];
githubTeams = [ "SDL" ];
scope = "Maintain core SDL libraries.";
shortName = "SDL";
enableFeatureFreezePing = true;
};
sphinx = {
+3
View File
@@ -1994,6 +1994,9 @@
"sec-release-25.05-notable-changes": [
"release-notes.html#sec-release-25.05-notable-changes"
],
"sec-release-25.05-wiki": [
"release-notes.html#sec-release-25.05-wiki"
],
"sec-nixpkgs-release-25.05": [
"release-notes.html#sec-nixpkgs-release-25.05"
],
@@ -3,6 +3,7 @@
This section lists the release notes for each stable version of NixOS and current unstable revision.
```{=include=} sections
rl-2511.section.md
rl-2505.section.md
rl-2411.section.md
rl-2405.section.md
@@ -646,6 +646,10 @@
<!-- To avoid merge conflicts, consider adding your item at an arbitrary place in the list instead. -->
## NixOS Wiki {#sec-release-25.05-wiki}
The official NixOS Wiki at [wiki.nixos.org](https://wiki.nixos.org) has new and improved articles, new contributors and some improvements in its dark theme and mobile readability.
```{=include=} sections
../release-notes-nixpkgs/rl-2505.section.md
```
@@ -1,4 +1,4 @@
# Release 25.11 (2025.11/??) {#sec-release-25.11}
# Release 25.11 ("Xantusia", 2025.11/??) {#sec-release-25.11}
## Highlights {#sec-release-25.11-highlights}
@@ -45,7 +45,7 @@ let
# To be able to open the firewall, we need to read out port values in the
# server properties, but fall back to the defaults when those don't exist.
# These defaults are from https://minecraft.gamepedia.com/Server.properties#Java_Edition_3
# These defaults are from https://minecraft.wiki/w/Server.properties#Java_Edition
defaultServerPort = 25565;
serverPort = cfg.serverProperties.server-port or defaultServerPort;
@@ -93,10 +93,8 @@ in
type = lib.types.bool;
default = false;
description = ''
Whether you agree to
[
Mojangs EULA](https://account.mojang.com/documents/minecraft_eula). This option must be set to
`true` to run Minecraft server.
Whether you agree to [Mojangs EULA](https://www.minecraft.net/eula).
This option must be set to `true` to run Minecraft server.
'';
};
@@ -167,10 +165,10 @@ in
}
'';
description = ''
Minecraft server properties for the server.properties file. Only has
Minecraft server properties forthe server.properties file. Only has
an effect when {option}`services.minecraft-server.declarative`
is set to `true`. See
<https://minecraft.gamepedia.com/Server.properties#Java_Edition_3>
<https://minecraft.wiki/w/Server.properties#Java_Edition>
for documentation on these values.
'';
};
@@ -182,7 +180,7 @@ in
jvmOpts = lib.mkOption {
type = lib.types.separatedString " ";
default = "-Xmx2048M -Xms2048M";
# Example options from https://minecraft.gamepedia.com/Tutorials/Server_startup_script
# Example options from https://minecraft.wiki/w/Tutorial:Server_startup_script
example =
"-Xms4092M -Xmx4092M -XX:+UseG1GC -XX:+CMSIncrementalPacing "
+ "-XX:+CMSClassUnloadingEnabled -XX:ParallelGCThreads=2 "
@@ -633,6 +633,7 @@ in
in
{
Restart = "always";
RestartSec = "5s";
Type = "simple";
User = cfg.user;
Group = cfg.group;
-2
View File
@@ -41,8 +41,6 @@ let
if [ "$(readlink "$out/etc/$target")" != "$src" ]; then
echo "mismatched duplicate entry $(readlink "$out/etc/$target") <-> $src"
ret=1
continue
fi
fi
+8 -5
View File
@@ -632,6 +632,7 @@ let
grubUseEfi ? false,
enableOCR ? false,
meta ? { },
passthru ? { },
testSpecialisationConfig ? false,
testFlakeSwitch ? false,
testByAttrSwitch ? false,
@@ -644,7 +645,7 @@ let
isEfi = bootLoader == "systemd-boot" || (bootLoader == "grub" && grubUseEfi);
in
makeTest {
inherit enableOCR;
inherit enableOCR passthru;
name = "installer-" + name;
meta = {
# put global maintainers here, individuals go into makeInstallerTest fkt call
@@ -1109,10 +1110,12 @@ in
# The (almost) simplest partitioning scheme: a swap partition and
# one big filesystem partition.
simple = makeInstallerTest "simple" simple-test-config;
lix-simple = makeInstallerTest "simple" simple-test-config // {
selectNixPackage = pkgs: pkgs.lix;
};
simple = makeInstallerTest "simple" (
simple-test-config
// {
passthru.override = args: makeInstallerTest "simple" simple-test-config // args;
}
);
switchToFlake = makeInstallerTest "switch-to-flake" simple-test-config-flake;
+8 -12
View File
@@ -3,20 +3,16 @@
let
inherit (pkgs) lib;
tests = {
default = testsForPackage { nixPackage = pkgs.nix; };
lix = testsForPackage { nixPackage = pkgs.lix; };
};
tests.default = testsForPackage { nixPackage = pkgs.nix; };
testsForPackage =
args:
lib.recurseIntoAttrs {
# If the attribute is not named 'test'
# You will break all the universe on the release-*.nix side of things.
# `discoverTests` relies on `test` existence to perform a `callTest`.
test = testMiscFeatures args;
passthru.override = args': testsForPackage (args // args');
testsForPackage = args: {
# If the attribute is not named 'test'
# You will break all the universe on the release-*.nix side of things.
# `discoverTests` relies on `test` existence to perform a `callTest`.
test = testMiscFeatures args // {
passthru.override = args': (testsForPackage (args // args')).test;
};
};
testMiscFeatures =
{ nixPackage, ... }:
@@ -137,6 +137,19 @@ final: prev: {
meta.hydraPlatforms = [ ];
};
GPTModels-nvim = buildVimPlugin {
pname = "GPTModels.nvim";
version = "2025-05-15";
src = fetchFromGitHub {
owner = "Aaronik";
repo = "GPTModels.nvim";
rev = "04d91c778d74f762143203ab81e155eec642b5f6";
sha256 = "06spvkfc1bhckq8w56w6ha4gzk60wfhjlyivrx51awz20sd6hyw0";
};
meta.homepage = "https://github.com/Aaronik/GPTModels.nvim/";
meta.hydraPlatforms = [ ];
};
Improved-AnsiEsc = buildVimPlugin {
pname = "Improved-AnsiEsc";
version = "2015-08-26";
@@ -8917,12 +8930,12 @@ final: prev: {
neogit = buildVimPlugin {
pname = "neogit";
version = "2025-04-16";
version = "2025-05-15";
src = fetchFromGitHub {
owner = "NeogitOrg";
repo = "neogit";
rev = "9bb1e73c534f767607e0a888f3de4c942825c501";
sha256 = "06qcyz3snk8bphbd2n9q4dzizkksn65is0nksd76q0zzkvb9qxhp";
rev = "6de4b9f9a92917f9aea3a0dbdc3dbbedc11d26be";
sha256 = "0z9qri9sp1aicma1yiy2vkdjixjj7pbprd86nmslrhrnchvnqrbh";
};
meta.homepage = "https://github.com/NeogitOrg/neogit/";
meta.hydraPlatforms = [ ];
@@ -1314,6 +1314,13 @@ in
];
};
GPTModels-nvim = super.GPTModels-nvim.overrideAttrs {
dependencies = with self; [
nui-nvim
telescope-nvim
];
};
guard-collection = super.guard-collection.overrideAttrs {
dependencies = [ self.guard-nvim ];
};
@@ -9,6 +9,7 @@ https://github.com/whonore/Coqtail/,,
https://github.com/vim-scripts/DoxygenToolkit.vim/,,
https://github.com/numToStr/FTerm.nvim/,,
https://github.com/antoinemadec/FixCursorHold.nvim/,,
https://github.com/Aaronik/GPTModels.nvim/,HEAD,
https://github.com/vim-scripts/Improved-AnsiEsc/,,
https://github.com/ionide/Ionide-vim/,HEAD,
https://github.com/martinda/Jenkinsfile-vim-syntax/,,
@@ -27,8 +27,8 @@ let
mktplcRef = {
name = "language-x86-64-assembly";
publisher = "13xforever";
version = "3.1.4";
hash = "sha256-FJRDm1H3GLBfSKBSFgVspCjByy9m+j9OStlU+/pMfs8=";
version = "3.1.5";
hash = "sha256-WIhmAZLR2WOSqQF3ozJ/Vr3Rp6HdSK7L23T3h4AVaGM=";
};
meta = {
description = "Cutting edge x86 and x86_64 assembly syntax highlighting";
@@ -89,8 +89,8 @@ let
mktplcRef = {
publisher = "42Crunch";
name = "vscode-openapi";
version = "4.33.1";
hash = "sha256-iq0UpVaZMOzh4NIRPLk49ciFuO4A6PDSEMe1KKhfSxA=";
version = "4.33.2";
hash = "sha256-agCxi2UhJitdQmHIf6rK7WexkfljUQdqK5rLqzV4J6o=";
};
meta = {
changelog = "https://marketplace.visualstudio.com/items/42Crunch.vscode-openapi/changelog";
@@ -4027,8 +4027,8 @@ let
mktplcRef = {
publisher = "redhat";
name = "java";
version = "1.41.2025031208";
hash = "sha256-0VWLkztB7anIs19QN1yPQvVjNim+DICv43IOMwEaM+E=";
version = "1.42.0";
hash = "sha256-m6RJm8eleMjDNy5ixfXWtOcPmsjNynCUNuF9lsCB8ho=";
};
buildInputs = [ jdk ];
meta = {
@@ -8,8 +8,8 @@ vscode-utils.buildVscodeMarketplaceExtension {
mktplcRef = {
publisher = "RooVeterinaryInc";
name = "roo-cline";
version = "3.16.5";
hash = "sha256-UbOLY1qHYOoMQq3Agm2qI2+I6YLwv2kec6nqPyGZha4=";
version = "3.17.1";
hash = "sha256-gfzn0KulOHUKcG3LNF7+g7VwkDHR4BYsmq730Uuv2ZU=";
};
passthru.updateScript = vscode-extension-update-script { };
@@ -76,7 +76,7 @@ in
gnum4,
gtk3,
icu73,
icu77,
icu77, # if you fiddle with the icu parameters, please check Thunderbird's overrides
libGL,
libGLU,
libevent,
@@ -40,11 +40,11 @@
python3.pkgs.buildPythonApplication rec {
pname = "gajim";
version = "2.1.1";
version = "2.2.0";
src = fetchurl {
url = "https://gajim.org/downloads/${lib.versions.majorMinor version}/gajim-${version}.tar.gz";
hash = "sha256-1pPrc7lzxaLK1QbxslGYGS8xOxuT231RvZrdvWeGFOk=";
hash = "sha256-TOZuMiE5RjaJYvNWxl2FyCp6uIO+LLWiRb7N9jc1yRk=";
};
format = "pyproject";
@@ -5,23 +5,28 @@
callPackage,
fetchurl,
icu73,
icu77,
fetchpatch2,
config,
}:
let
icu73' = icu73.overrideAttrs (attrs: {
# standardize vtzone output
# Work around ICU-22132 https://unicode-org.atlassian.net/browse/ICU-22132
# https://bugzilla.mozilla.org/show_bug.cgi?id=1790071
patches = attrs.patches ++ [
(fetchpatch2 {
url = "https://hg.mozilla.org/mozilla-central/raw-file/fb8582f80c558000436922fb37572adcd4efeafc/intl/icu-patches/bug-1790071-ICU-22132-standardize-vtzone-output.diff";
stripLen = 3;
hash = "sha256-MGNnWix+kDNtLuACrrONDNcFxzjlUcLhesxwVZFzPAM=";
})
];
});
patchICU =
icu:
icu.overrideAttrs (attrs: {
# standardize vtzone output
# Work around ICU-22132 https://unicode-org.atlassian.net/browse/ICU-22132
# https://bugzilla.mozilla.org/show_bug.cgi?id=1790071
patches = attrs.patches ++ [
(fetchpatch2 {
url = "https://hg.mozilla.org/mozilla-central/raw-file/fb8582f80c558000436922fb37572adcd4efeafc/intl/icu-patches/bug-1790071-ICU-22132-standardize-vtzone-output.diff";
stripLen = 3;
hash = "sha256-MGNnWix+kDNtLuACrrONDNcFxzjlUcLhesxwVZFzPAM=";
})
];
});
icu73' = patchICU icu73;
icu77' = patchICU icu77;
common =
{
@@ -52,6 +57,7 @@ let
extraPassthru = {
icu73 = icu73';
icu77 = icu77';
};
meta = with lib; {
@@ -78,6 +84,7 @@ let
pgoSupport = false; # console.warn: feeds: "downloadFeed: network connection unavailable"
icu73 = icu73';
icu77 = icu77';
};
in
+7 -6
View File
@@ -8,22 +8,22 @@
rustPlatform.buildRustPackage (finalAttrs: {
pname = "amazon-q-cli";
version = "1.9.1";
version = "1.10.0";
src = fetchFromGitHub {
owner = "aws";
repo = "amazon-q-developer-cli";
tag = "v${finalAttrs.version}";
hash = "sha256-BiVCiMBL5LLm8RYw58u6P7yqQq9XnN8b6fTbxNE2QsA=";
hash = "sha256-X1L3Nrzchp8yuGGBwwLQ4ZE41GKH3pFR2CX77TYYhNo=";
};
useFetchCargoVendor = true;
cargoHash = "sha256-7zUgWLGTZx3Ex7RYxb3eZimWdy6AxkNwpCDUwiAr2JE=";
cargoHash = "sha256-qtQ+e0NRzzGn0s2zpnMNUv7JdQDuImMfyC0C/QZrpjU=";
cargoBuildFlags = [
"-p"
"q_cli"
"chat_cli"
];
nativeBuildInputs = [
@@ -31,12 +31,12 @@ rustPlatform.buildRustPackage (finalAttrs: {
];
postInstall = ''
install -m 0755 $out/bin/q_cli $out/bin/amazon-q
install -m 0755 $out/bin/chat_cli $out/bin/amazon-q
'';
cargoTestFlags = [
"-p"
"q_cli"
"chat_cli"
];
# skip integration tests that have external dependencies
@@ -60,6 +60,7 @@ rustPlatform.buildRustPackage (finalAttrs: {
"--skip=init_lint_zsh_post_zshrc"
"--skip=init_lint_zsh_pre_zprofile"
"--skip=init_lint_zsh_pre_zshrc"
"--skip=telemetry::cognito::test::pools"
];
doInstallCheck = true;
+2 -2
View File
@@ -6,11 +6,11 @@
stdenvNoCC.mkDerivation rec {
pname = "amiri";
version = "1.001";
version = "1.002";
src = fetchzip {
url = "https://github.com/alif-type/amiri/releases/download/${version}/Amiri-${version}.zip";
hash = "sha256-YwiDY5/Ty5Pwj3d8+UafUNLVZ3omRtFRWQCLn2RkheM=";
hash = "sha256-Ln2AFiQ5hX4w1yu5NCF28S0hmfWUhEINi1YJVV/Gngo=";
};
installPhase = ''
+4 -4
View File
@@ -11,11 +11,11 @@
stdenv.mkDerivation rec {
pname = "bird";
version = "3.0.2";
version = "3.1.1";
src = fetchurl {
url = "https://bird.network.cz/download/bird-${version}.tar.gz";
hash = "sha256-eKqL5820LfFLnilpu2Q7IoxoBMZXj5CTsXPOiiQ3zDA=";
url = "https://bird.nic.cz/download/bird-${version}.tar.gz";
hash = "sha256-KXJRl0/4g+TvA/zNbJEtEW7Un/Lxxjtm0dul8HCUREo=";
};
nativeBuildInputs = [
@@ -43,7 +43,7 @@ stdenv.mkDerivation rec {
meta = with lib; {
changelog = "https://gitlab.nic.cz/labs/bird/-/blob/v${version}/NEWS";
description = "BIRD Internet Routing Daemon";
homepage = "https://bird.network.cz";
homepage = "https://bird.nic.cz/";
license = licenses.gpl2Plus;
maintainers = with maintainers; [ herbetom ];
platforms = platforms.linux;
+9 -4
View File
@@ -18,13 +18,13 @@ let
in
stdenv.mkDerivation (finalAttrs: {
pname = "cherry-studio";
version = "1.3.2";
version = "1.3.4";
src = fetchFromGitHub {
owner = "CherryHQ";
repo = "cherry-studio";
tag = "v${finalAttrs.version}";
hash = "sha256-Tgd8MvxsiCDp2pdtz2MeCnTGY4Butw9V/UoTw0XEaIg=";
hash = "sha256-xCS8ZomIAVEnQ2SJRay/ii7xhPMO+ctc8C14Xrje8kI=";
};
postPatch = ''
@@ -41,7 +41,7 @@ stdenv.mkDerivation (finalAttrs: {
offlineCache = yarn-berry.fetchYarnBerryDeps {
inherit (finalAttrs) src missingHashes;
hash = "sha256-WUsG8mqozphU2YIT73KqMNP62TBiay3EiGrMBgd2QJw=";
hash = "sha256-cStjxlmOnoDfrt6z5jvpkHfIKyfZ9UFWbbZjnJLiTu4=";
};
nativeBuildInputs = [
@@ -89,7 +89,12 @@ stdenv.mkDerivation (finalAttrs: {
runHook preInstall
mkdir -p $out/opt/cherry-studio
cp -r dist/linux-unpacked/{resources,LICENSE*} $out/opt/cherry-studio
${
if stdenv.hostPlatform.isAarch64 then
"cp -r dist/linux-arm64-unpacked/{resources,LICENSE*} $out/opt/cherry-studio"
else
"cp -r dist/linux-unpacked/{resources,LICENSE*} $out/opt/cherry-studio"
}
install -Dm644 build/icon.png $out/share/pixmaps/cherry-studio.png
makeWrapper ${lib.getExe electron} $out/bin/cherry-studio \
--inherit-argv0 \
+2 -2
View File
@@ -7,13 +7,13 @@
buildGoModule rec {
pname = "circleci-cli";
version = "0.1.31543";
version = "0.1.31632";
src = fetchFromGitHub {
owner = "CircleCI-Public";
repo = pname;
rev = "v${version}";
sha256 = "sha256-0hikYA7oU3tTHZdEcxDzMXCg13+muk6V7MyqJwExm0A=";
sha256 = "sha256-3ufazu7DuUFp3aBxQ5MPlndECHSjvEIscYjlvE3j9G8=";
};
vendorHash = "sha256-H7q373HL6M6ETkXEY5tAwN32rx0eMkqRAAZ4kQf9rKk=";
+2 -2
View File
@@ -9,13 +9,13 @@
buildGoModule rec {
pname = "cloudflared";
version = "2025.4.0";
version = "2025.5.0";
src = fetchFromGitHub {
owner = "cloudflare";
repo = "cloudflared";
tag = version;
hash = "sha256-PKF7wP/ueLLhV8k3nMUm/c5fkg+7CwRf1oLnx0qbcA0=";
hash = "sha256-ZnkE9x4A9HoiSXzvYuzyW/dH08r0aJUk/q6gFVgtTjk=";
};
vendorHash = null;
@@ -0,0 +1,37 @@
{
fetchFromGitHub,
lib,
stdenv,
}:
stdenv.mkDerivation {
pname = "finalmouse-udev-rules";
version = "0-unstable-2025-05-05";
src = fetchFromGitHub {
owner = "teamfinalmouse";
repo = "xpanel-linux-permissions";
rev = "60c4ed794bd946e467559cc572cf25bb99bf04b6";
hash = "sha256-E2xhm+8fFlxgIKjZlAvosLk/KgbmLk01BjK++y8laBc=";
};
dontUnpack = true;
installPhase = ''
runHook preInstall
install -Dpm644 $src/99-finalmouse.rules $out/lib/udev/rules.d/70-finalmouse.rules
runHook postInstall
'';
meta = {
homepage = "https://github.com/teamfinalmouse/xpanel-linux-permissions";
description = "udev rules that give NixOS permission to communicate with Finalmouse mice";
platforms = lib.platforms.linux;
license = lib.licenses.mit;
maintainers = with lib.maintainers; [
emilia
];
};
}
+2 -2
View File
@@ -49,14 +49,14 @@ let
in
stdenv.mkDerivation (finalAttrs: {
pname = "gamescope";
version = "3.16.7";
version = "3.16.9";
src = fetchFromGitHub {
owner = "ValveSoftware";
repo = "gamescope";
tag = finalAttrs.version;
fetchSubmodules = true;
hash = "sha256-q0yTOyu47tQXorFfnmRa4wrt0KRnyelLDmfcg4iwPfs=";
hash = "sha256-Dw9EErOINGoOlnNqroKR+fbRfMGL7Q13gP3E5iw4RhU=";
};
patches = [
+42
View File
@@ -0,0 +1,42 @@
{
lib,
buildGoModule,
fetchFromGitHub,
}:
buildGoModule rec {
pname = "goctl";
version = "1.8.3";
src = fetchFromGitHub {
owner = "zeromicro";
repo = "go-zero";
tag = "v${version}";
hash = "sha256-v5WzqMotF9C7i9hTYSjaPmTwveBVDVn+SKQXYuS4Rdc=";
};
vendorHash = "sha256-tOIlfYiAI9m7oTZyPDCzTXg9XTwBb6EOVLzDfZnzL4E=";
modRoot = "tools/goctl";
subPackages = [ "." ];
doCheck = true;
ldflags = [
"-s"
"-w"
];
meta = {
description = "CLI handcuffle of go-zero, a cloud-native Go microservices framework";
longDescription = ''
goctl is a go-zero's built-in handcuffle that is a major
lever to increase development efficiency, generating code,
document, deploying k8s yaml, dockerfile, etc.
'';
homepage = "https://go-zero.dev";
license = lib.licenses.mit;
maintainers = with lib.maintainers; [ cococolanosugar ];
mainProgram = "goctl";
};
}
+1 -1
View File
@@ -59,7 +59,7 @@ stdenv.mkDerivation (finalAttrs: {
homepage = "https://www.gnu.org/software/guile-sdl/";
description = "Guile bindings for SDL";
license = lib.licenses.gpl3Plus;
teams = [ lib.teams.sdl ];
maintainers = [ ];
inherit (guile.meta) platforms;
};
})
File diff suppressed because it is too large Load Diff
+38
View File
@@ -0,0 +1,38 @@
{
lib,
buildNpmPackage,
fetchFromGitHub,
nix-update-script,
}:
buildNpmPackage (finalAttrs: {
pname = "hypercore";
version = "11.7.0";
src = fetchFromGitHub {
owner = "holepunchto";
repo = "hypercore";
tag = "v${finalAttrs.version}";
hash = "sha256-ZAKWFSOIAQysK9+4YxbUiL0fVsqnGFqhwe9ps6ZXYv0=";
};
npmDepsHash = "sha256-ZJxVmQWKgHyKkuYfGIlANXFcROjI7fibg6mxIhDZowM=";
dontNpmBuild = true;
postPatch = ''
cp ${./package-lock.json} ./package-lock.json
'';
passthru.updateScript = nix-update-script { };
meta = {
description = "Secure, distributed append-only log";
homepage = "https://github.com/holepunchto/hypercore";
license = lib.licenses.mit;
teams = with lib.teams; [ ngi ];
maintainers = [ lib.maintainers.goodylove ];
platforms = lib.platforms.all;
};
})
+11 -49
View File
@@ -1,8 +1,8 @@
diff --git a/admin/Makefile.def b/admin/Makefile.def
index 43ef322..cad3de2 100644
index facc205..0daceaf 100644
--- a/admin/Makefile.def
+++ b/admin/Makefile.def
@@ -306,7 +306,7 @@ endif
@@ -310,7 +310,7 @@ endif
# Apple CLANG flags (identical to GCC)
ifeq ($(GAG_COMPILER_CKIND),clang)
@@ -11,7 +11,7 @@ index 43ef322..cad3de2 100644
ifeq ($(RELEASE_MODE),no)
OPTION_CFLAGS += -Wall
endif
@@ -356,7 +356,7 @@ endif
@@ -360,7 +360,7 @@ endif
# GFORTRAN flags
ifeq ($(GAG_COMPILER_FKIND),gfortran)
@@ -21,55 +21,17 @@ index 43ef322..cad3de2 100644
GLOBAL_FFLAGS += -fsanitize=address -fsanitize=null
# Can not be used with our memory(ip):
diff --git a/admin/define-system.sh b/admin/define-system.sh
index f68274d..dd1a9be 100644
index 36d4ab9..0233259 100644
--- a/admin/define-system.sh
+++ b/admin/define-system.sh
@@ -279,35 +279,22 @@ EOF
else
GAG_MACHINE=pc
fi
- if which gcc > /dev/null 2>&1; then
- DEFAULT_CCOMPILER=gcc
- fi
- if which g++ > /dev/null 2>&1; then
- DEFAULT_CXXCOMPILER=g++
- elif which clang++ > /dev/null 2>&1; then
- DEFAULT_CXXCOMPILER=clang++
- fi
- if which ifort > /dev/null 2>&1; then
- DEFAULT_FCOMPILER=ifort
- elif which gfortran > /dev/null 2>&1; then
- DEFAULT_FCOMPILER=gfortran
- fi
@@ -287,8 +287,8 @@ EOF
fi
elif [ `uname -p` = "arm" ]; then
defsys_message "WARNING: experimental ARM support"
GAG_MACHINE=arm64
- if which gcc > /dev/null 2>&1; then
- DEFAULT_CCOMPILER=gcc
- fi
- if which g++ > /dev/null 2>&1; then
- DEFAULT_CXXCOMPILER=g++
- elif which clang++ > /dev/null 2>&1; then
- DEFAULT_CXXCOMPILER=clang++
- fi
- if which ifort > /dev/null 2>&1; then
- DEFAULT_FCOMPILER=ifort
- elif which gfortran > /dev/null 2>&1; then
- DEFAULT_FCOMPILER=gfortran
- fi
+ fi
+ if which clang > /dev/null 2>&1; then
+ DEFAULT_CCOMPILER=clang
+ fi
+ if which clang++ > /dev/null 2>&1; then
+ DEFAULT_CXXCOMPILER=clang++
+ elif which g++ > /dev/null 2>&1; then
+ DEFAULT_CXXCOMPILER=g++
+ fi
+ if which ifort > /dev/null 2>&1; then
+ DEFAULT_FCOMPILER=ifort
+ elif which gfortran > /dev/null 2>&1; then
+ DEFAULT_FCOMPILER=gfortran
fi ;;
CYGWIN*)
if [ `uname -m | grep -c "x86_64"` -ne 0 ]; then
+ if which clang > /dev/null 2>&1; then
+ DEFAULT_CCOMPILER=clang
fi
if which clang++ > /dev/null 2>&1; then
DEFAULT_CXXCOMPILER=clang++
+3 -6
View File
@@ -26,15 +26,15 @@ let
in
stdenv.mkDerivation (finalAttrs: {
version = "4.4-01";
version = "4.5-01";
pname = "imager";
src = fetchurl {
# The recommended download link is on Nextcloud instance that
# requires to accept some general terms of use. Use a mirror at
# univ-grenoble-alpes.fr instead.
url = "https://cloud.univ-grenoble-alpes.fr/s/J6yEqA6yZ8tX9da/download?path=%2F&files=imager-dec24.tar.gz";
hash = "sha256-Pq92IsGY4heekm5zNGngnp6J6YiCHYAyuMT2RsD1/9o=";
url = "https://cloud.univ-grenoble-alpes.fr/s/J6yEqA6yZ8tX9da/download?path=%2F&files=imager-may25.tar.gz";
hash = "sha256-E3JjdVGEQ0I/ogYj0G1OZxfQ3hA+sRgA4LAfHK52Sec=";
};
nativeBuildInputs = [
@@ -55,9 +55,6 @@ stdenv.mkDerivation (finalAttrs: {
];
patches = [
# Update the Python link flag script from Gildas upstream
# version. This patch will be included in the the IMAGER release.
./python-ldflags.patch
# Use Clang as the default compiler on Darwin.
./clang.patch
# Replace hardcoded cpp with GAG_CPP (see below).
-104
View File
@@ -1,104 +0,0 @@
diff --git a/app/main/src-tauri/tauri.conf.json b/app/main/src-tauri/tauri.conf.json
index 1114b19..c4cc8f4 100644
--- a/app/main/src-tauri/tauri.conf.json
+++ b/app/main/src-tauri/tauri.conf.json
@@ -23,7 +23,6 @@
"macOS": {
"frameworks": [],
"exceptionDomain": "",
- "signingIdentity": "-",
"providerShortName": null,
"entitlements": null
},
+3 -3
View File
@@ -16,19 +16,19 @@
rustPlatform.buildRustPackage (finalAttrs: {
pname = "ruff";
version = "0.11.9";
version = "0.11.10";
src = fetchFromGitHub {
owner = "astral-sh";
repo = "ruff";
tag = finalAttrs.version;
hash = "sha256-TJHBaru0L2pMdZ9omtJ+OqGP764fSwoP54xndWVV6ls=";
hash = "sha256-8psRFBhOzcFYYOU1aLf2tQwSZeWyn3TjUtfMR8HJ4FE=";
};
cargoBuildFlags = [ "--package=ruff" ];
useFetchCargoVendor = true;
cargoHash = "sha256-/xIQ8JJI2WfX3rxLZQCwsN2ylURqi+SjkBvnn0Hdij0=";
cargoHash = "sha256-KwTqm345bRwn5PXn/bTakiBNNjJCIstkXGpqtyCiK4k=";
nativeBuildInputs = [ installShellFiles ];
+3
View File
@@ -73,5 +73,8 @@ rustPlatform.buildRustPackage rec {
platforms = [ "x86_64-linux" ];
maintainers = with maintainers; [ gaelreyrol ];
mainProgram = "scaphandre";
# Upstream needs to decide what to do about a broken dependency
# https://github.com/hubblo-org/scaphandre/issues/403
broken = true;
};
}
@@ -1,13 +0,0 @@
--- a/attacher.c 2025-02-24 20:15:31.701820351 +0100
+++ b/attacher.c 2025-02-24 20:17:05.893826559 +0100
@@ -461,8 +461,8 @@
size_t len;
len = strlen(*av) + 1;
if (p + len >= m.m.command.cmd + ARRAY_SIZE(m.m.command.cmd) - 1)
- break;
+ Panic(0, "Total length of the command to send too large.\n");
- strncpy(p, *av, MAXPATHLEN);
+ memcpy(p, *av, len);
p += len;
}
*p = 0;
+2 -9
View File
@@ -10,11 +10,11 @@
stdenv.mkDerivation rec {
pname = "screen";
version = "5.0.0";
version = "5.0.1";
src = fetchurl {
url = "mirror://gnu/screen/screen-${version}.tar.gz";
hash = "sha256-8Eo50AoOXHyGpVM4gIkDCCrV301z3xov00JZdq7ZSXE=";
hash = "sha256-La429Ns3n/zRS2kVlrpuwYrDqeIrxHrCOXiatYQJhp0=";
};
configureFlags = [
@@ -25,13 +25,6 @@ stdenv.mkDerivation rec {
# We need _GNU_SOURCE so that mallocmock_reset() is defined: https://savannah.gnu.org/bugs/?66416
NIX_CFLAGS_COMPILE = "-D_GNU_SOURCE=1 -Wno-int-conversion -Wno-incompatible-pointer-types";
patches = [
# GNU Screen 5.0 uses strncpy incorrectly in SendCmdMessage
# This causes issues detected when using -D_FORTIFY_SOURCE=3
# e.g. https://savannah.gnu.org/bugs/index.php?66215
./buffer-overflow-SendCmdMessage.patch
];
nativeBuildInputs = [
autoreconfHook
];
+1
View File
@@ -48,6 +48,7 @@ stdenv.mkDerivation rec {
mainProgram = "playsound";
platforms = platforms.unix;
license = licenses.zlib;
teams = [ lib.teams.sdl ];
homepage = "https://www.icculus.org/SDL_sound/";
};
}
+1 -1
View File
@@ -32,7 +32,7 @@ stdenv.mkDerivation {
description = "SDL 1.2 patched with libsixel support";
license = lib.licenses.lgpl21;
mainProgram = "sdl-config";
teams = [ lib.teams.sdl ];
maintainers = [ ];
platforms = lib.platforms.linux;
};
}
+1 -1
View File
@@ -30,7 +30,7 @@ stdenv.mkDerivation (finalAttrs: {
homepage = "https://sdl-stretch.sourceforge.net/";
description = "Stretch Functions For SDL";
license = lib.licenses.lgpl2;
teams = [ lib.teams.sdl ];
maintainers = [ ];
inherit (SDL.meta) platforms;
};
})
+1 -2
View File
@@ -103,9 +103,8 @@ stdenv.mkDerivation (finalAttrs: {
license = lib.licenses.zlib;
maintainers = with lib.maintainers; [
nadiaholmquist
grimmauld
marcin-serwin
];
teams = [ lib.teams.sdl ];
platforms = lib.platforms.all;
pkgConfigModules = [
"sdl2-compat"
+1
View File
@@ -79,6 +79,7 @@ stdenv.mkDerivation (finalAttrs: {
homepage = "https://github.com/libsdl-org/SDL_image";
license = lib.licenses.zlib;
maintainers = [ lib.maintainers.evythedemon ];
teams = [ lib.teams.sdl ];
inherit (sdl3.meta) platforms;
};
})
+1
View File
@@ -62,6 +62,7 @@ stdenv.mkDerivation (finalAttrs: {
charain
Emin017
];
teams = [ lib.teams.sdl ];
pkgConfigModules = [ "sdl3-ttf" ];
platforms = lib.platforms.all;
};
+1
View File
@@ -226,6 +226,7 @@ stdenv.mkDerivation (finalAttrs: {
changelog = "https://github.com/libsdl-org/SDL/releases/tag/${finalAttrs.src.tag}";
license = lib.licenses.zlib;
maintainers = with lib.maintainers; [ getchoo ];
teams = [ lib.teams.sdl ];
platforms = lib.platforms.unix ++ lib.platforms.windows;
pkgConfigModules = [ "sdl3" ];
};
+2 -2
View File
@@ -8,14 +8,14 @@
python3Packages.buildPythonApplication rec {
pname = "snowflake-cli";
version = "3.7.1";
version = "3.7.2";
pyproject = true;
src = fetchFromGitHub {
owner = "snowflakedb";
repo = "snowflake-cli";
tag = "v${version}";
hash = "sha256-UhxjyXG2FQFhzhGjnmWSZr1LiW2/RHFvIAbvJP0I7oc=";
hash = "sha256-MCJl6Mkkkp9JkG+8ZNfWAYQFMJccdtKfPdcnfaY8Y3w=";
};
build-system = with python3Packages; [
+5 -5
View File
@@ -7,7 +7,7 @@
makeWrapper,
}:
let
version = "4.1.6";
version = "4.1.7";
inherit (stdenv.hostPlatform) system;
throwSystem = throw "tailwindcss has not been packaged for ${system} yet.";
@@ -22,10 +22,10 @@ let
hash =
{
aarch64-darwin = "sha256-vy5DrFSVROGpP4uvS32PtfSBWJbF/vpzE9L0/drOxLc=";
aarch64-linux = "sha256-BPkJ72DfdGdV9ajPO61hoNkhzCfmzZRt1A/sSKcbAok=";
x86_64-darwin = "sha256-PteOE9PWEtn7BNoVT/nw6tz4H5jBFyzOZmZGDxfaGVE=";
x86_64-linux = "sha256-BuaYnp+lBuNbzl3MMVo9xm2n+WJzQ3tb8UsPhgAhRlM=";
aarch64-darwin = "sha256-CjzOBmhnEW0c+V6utNKPROhAOx1ql2vG8S4G1hT6Wdo=";
aarch64-linux = "sha256-jEGaZiGW8FcmVRrQBr2DQfR7i+344MtlFofZrjwK4GY=";
x86_64-darwin = "sha256-TN7TKW561j9qvgadL/P/cQhhum1lCrsjNglhxgz9GSw=";
x86_64-linux = "sha256-BwYpKTWpdzxsh54X0jYlMi5EkOfo96CtDmiPquTe+YE=";
}
.${system} or throwSystem;
in
+3 -3
View File
@@ -10,17 +10,17 @@
rustPlatform.buildRustPackage rec {
pname = "tbtools";
version = "0.5.0";
version = "0.6.0";
src = fetchFromGitHub {
owner = "intel";
repo = "tbtools";
tag = "v${version}";
hash = "sha256-zq8q3JaoqWAQUat2gIW0Wimi/tZiC6XDphUVjH0viU4=";
hash = "sha256-xLMnB8KliwHVU5y4L7K0a43gfdhLKFxnAx4wxGL9xMc=";
};
useFetchCargoVendor = true;
cargoHash = "sha256-SAHIDjELm4qr4whoQVdt3EuNA72qFqXEg3H0hYr7yLc=";
cargoHash = "sha256-QuiDI2/XzhUKF7BGnoKeJ2143keJtmi+8WG1MpulLZo=";
nativeBuildInputs = [
pkg-config
+10 -10
View File
@@ -12,15 +12,15 @@
buildPackages,
}:
stdenv.mkDerivation rec {
stdenv.mkDerivation (finalAttrs: {
pname = "telescope";
version = "0.10.1";
version = "0.11";
src = fetchFromGitHub {
owner = "omar-polo";
repo = "telescope";
rev = version;
hash = "sha256-MVZ/pvDAETacQiEMEXM0gYM20LXqNiHtMfFGqS1vipY=";
tag = finalAttrs.version;
hash = "sha256-GKeUXa4RKYkoywrCrpenfLt10Rdj9L0xYI3tf2hFAbk=";
};
postPatch = ''
@@ -45,11 +45,11 @@ stdenv.mkDerivation rec {
"HOSTCC=${buildPackages.stdenv.cc}/bin/${buildPackages.stdenv.cc.targetPrefix}cc"
];
meta = with lib; {
meta = {
description = "Telescope is a w3m-like browser for Gemini";
homepage = "https://www.telescope-browser.org/";
license = licenses.isc;
maintainers = with maintainers; [ heph2 ];
platforms = platforms.unix;
homepage = "https://telescope-browser.org/";
license = lib.licenses.isc;
maintainers = with lib.maintainers; [ heph2 ];
platforms = lib.platforms.unix;
};
}
})
+3 -3
View File
@@ -12,16 +12,16 @@
buildGoModule rec {
pname = "trayscale";
version = "0.14.3";
version = "0.16.0";
src = fetchFromGitHub {
owner = "DeedleFake";
repo = "trayscale";
tag = "v${version}";
hash = "sha256-HIx3icecgu29jlrHpXfIXzJAxgKSgpeGexouiL2lYB8=";
hash = "sha256-Fvp75DaU/ZB4VZsUIgiSAg9eWU2JO6aGGwEYaC+VzIE=";
};
vendorHash = "sha256-hFUzFjQ8LWOKifDp3FiIUwdttX0FrPpRdtWj6fqE5uQ=";
vendorHash = "sha256-KC2eWO3pS8Xbq9FwWfT3bAodhxdTOzpvkBxzxPa9pUY=";
subPackages = [ "cmd/trayscale" ];
+3 -3
View File
@@ -7,16 +7,16 @@
}:
buildGoModule rec {
pname = "treefmt";
version = "2.2.1";
version = "2.3.0";
src = fetchFromGitHub {
owner = "numtide";
repo = "treefmt";
rev = "v${version}";
hash = "sha256-gNGDqCRPvXjbfDQkEP8UsEStL9fsvUVYWPv3d8o1Bq0=";
hash = "sha256-tDezwRWEfPz+u/i9Wz7MZULMmmIUwnl+5gcFU+dDj6Y=";
};
vendorHash = "sha256-47yOjk3eO5K0T01GUDvheJxoAJz0ZmiV2RdqTv01pYQ=";
vendorHash = "sha256-9yAvqz99YlBfFU/hGs1PB/sH0iOyWaVadqGhfXMkj5E=";
subPackages = [ "." ];
+35
View File
@@ -0,0 +1,35 @@
{
fetchFromGitHub,
lib,
nix-update-script,
rustPlatform,
versionCheckHook,
}:
rustPlatform.buildRustPackage (finalAttrs: {
pname = "tuistash";
version = "0.7.1";
src = fetchFromGitHub {
owner = "edmocosta";
repo = "tuistash";
tag = "v${finalAttrs.version}";
hash = "sha256-LWmH/xHvdiY6lC7gsRh2gX31b9Fh4fWekrVdQ++8moQ=";
};
cargoHash = "sha256-mLtzdWHC7HN+hju71WQQZ4nJDMzybEfjzckbfeu32Qo=";
doInstallCheck = true;
nativeInstallCheckInputs = [ versionCheckHook ];
passthru.updateScript = nix-update-script { };
meta = {
description = "Terminal User Interface for Logstash";
homepage = "https://github.com/edmocosta/tuistash";
changelog = "https://github.com/edmocosta/tuistash/blob/v${finalAttrs.version}/CHANGELOG.md";
license = [ lib.licenses.asl20 ];
maintainers = [ lib.maintainers.kpbaks ];
mainProgram = "tuistash";
};
})
+7 -4
View File
@@ -20,17 +20,17 @@
rustPlatform.buildRustPackage (finalAttrs: {
pname = "uv";
version = "0.7.3";
version = "0.7.4";
src = fetchFromGitHub {
owner = "astral-sh";
repo = "uv";
tag = finalAttrs.version;
hash = "sha256-8yQnBAAzt6kjg1F1AVdLX4z4at8+vCA4lcSclkzXXGw=";
hash = "sha256-Lj+qznkYIO7tu12Db2k6hzfh02Ph+Nj6n6j7ncTbPXE=";
};
useFetchCargoVendor = true;
cargoHash = "sha256-kPJrVHFJcw3tHvLm0ddn4iBoBNK1MDDF0WNcqFfmA4o=";
cargoHash = "sha256-awKbKDyU8r7pdPlce0a0mLavrfnvMssyf/VDD6LRm7Q=";
buildInputs = [
rust-jemalloc-sys
@@ -83,7 +83,10 @@ rustPlatform.buildRustPackage (finalAttrs: {
asl20
mit
];
maintainers = with lib.maintainers; [ GaetanLepage ];
maintainers = with lib.maintainers; [
GaetanLepage
prince213
];
mainProgram = "uv";
};
})
+28
View File
@@ -0,0 +1,28 @@
{
lib,
fetchFromGitea,
rustPlatform,
}:
rustPlatform.buildRustPackage (finalAttrs: {
pname = "uwu-colors";
version = "0.4.0";
src = fetchFromGitea {
domain = "codeberg.org";
owner = "q60";
repo = "uwu_colors";
tag = finalAttrs.version;
hash = "sha256-qzqfLTww0m1rv/7oJZrHMk63CtOk4RzY+Owx0oqlVzI=";
};
cargoHash = "sha256-R/IZUFr8Cir34c+C7Kq6FTFEERiInGMF8yFcC0uQ7Us=";
meta = {
description = "Simple LSP server made to display colors via textDocument/documentColor";
mainProgram = "uwu_colors";
homepage = "https://codeberg.org/q60/uwu_colors";
license = lib.licenses.unlicense;
maintainers = with lib.maintainers; [ vel ];
};
})
+74
View File
@@ -0,0 +1,74 @@
{
lib,
stdenv,
fetchFromGitLab,
eigen,
hidapi,
libopus,
libpulseaudio,
portaudio,
qt6,
qt6Packages,
rtaudio,
}:
stdenv.mkDerivation (finalAttrs: {
pname = "wfview";
version = "2.10";
src = fetchFromGitLab {
owner = "eliggett";
repo = "wfview";
rev = "v${finalAttrs.version}";
hash = "sha256-bFTblsDtFAakbSJfSfKgvoxd1DTSv++rxU6R3/uWo+4=";
};
patches = [
# Remove syscalls during build to make it reproducible
# We also need to adjust some header paths for darwin
./remove-hard-encodings.patch
];
buildInputs =
[
eigen
hidapi
libopus
portaudio
rtaudio
qt6.qtbase
qt6.qtserialport
qt6.qtmultimedia
qt6.qtwebsockets
qt6Packages.qcustomplot
]
++ lib.optionals stdenv.hostPlatform.isLinux [
libpulseaudio
];
nativeBuildInputs = with qt6; [
wrapQtAppsHook
qmake
];
env.LANG = "C.UTF-8";
qmakeFlags = [ "wfview.pro" ];
postInstall = lib.optionalString stdenv.hostPlatform.isDarwin ''
mkdir -pv $out/Applications
mv -v "$out/bin/wfview.app" $out/Applications
# wrap executable to $out/bin
makeWrapper "$out/Applications/wfview.app/Contents/MacOS/wfview" "$out/bin/wfview"
'';
meta = {
description = "Open-source software for the control of modern Icom radios";
homepage = "https://wfview.org/";
license = lib.licenses.gpl3Only;
platforms = lib.platforms.unix;
mainProgram = "wfview";
maintainers = with lib.maintainers; [ Cryolitia ];
};
})
@@ -0,0 +1,171 @@
diff --git a/audioconverter.h b/audioconverter.h
index d3cf510..308725d 100644
--- a/audioconverter.h
+++ b/audioconverter.h
@@ -20,13 +20,8 @@
#endif
/* Opus and Eigen */
-#ifndef Q_OS_LINUX
-#include "opus.h"
-#include <Eigen/Eigen>
-#else
#include "opus/opus.h"
#include <eigen3/Eigen/Eigen>
-#endif
#include "wfviewtypes.h"
diff --git a/audiodevices.h b/audiodevices.h
index 3521eb5..0569e49 100644
--- a/audiodevices.h
+++ b/audiodevices.h
@@ -13,11 +13,7 @@
#include <QFontMetrics>
#include <portaudio.h>
-#ifndef Q_OS_LINUX
-#include "RtAudio.h"
-#else
#include "rtaudio/RtAudio.h"
-#endif
#include "wfviewtypes.h"
diff --git a/rthandler.h b/rthandler.h
index b422cc2..02b1117 100644
--- a/rthandler.h
+++ b/rthandler.h
@@ -6,11 +6,7 @@
#include <QThread>
#include <QMutex>
-#ifndef Q_OS_LINUX
-#include "RtAudio.h"
-#else
#include "rtaudio/RtAudio.h"
-#endif
#include <QAudioFormat>
diff --git a/tciserver.h b/tciserver.h
index 9b38886..af56763 100644
--- a/tciserver.h
+++ b/tciserver.h
@@ -9,13 +9,8 @@
#include "cachingqueue.h"
/* Opus and Eigen */
-#ifndef Q_OS_LINUX
-#include "opus.h"
-#include <Eigen/Eigen>
-#else
#include "opus/opus.h"
#include <eigen3/Eigen/Eigen>
-#endif
#define TCI_AUDIO_LENGTH 4096
struct tciCommandStruct
diff --git a/wfmain.h b/wfmain.h
index 0404fda..e400a74 100644
--- a/wfmain.h
+++ b/wfmain.h
@@ -68,11 +68,7 @@
#include <memory>
#include <portaudio.h>
-#ifndef Q_OS_LINUX
-#include "RtAudio.h"
-#else
#include "rtaudio/RtAudio.h"
-#endif
#ifdef USB_CONTROLLER
#ifdef Q_OS_WIN
diff --git a/wfview.pro b/wfview.pro
index a0943bd..e8f97e1 100644
--- a/wfview.pro
+++ b/wfview.pro
@@ -62,10 +62,8 @@ win32:DEFINES += __WINDOWS_WASAPI__
#linux:DEFINES += __LINUX_OSS__
linux:DEFINES += __LINUX_PULSE__
macx:DEFINES += __MACOSX_CORE__
-!linux:SOURCES += ../rtaudio/RTAudio.cpp
-!linux:HEADERS += ../rtaudio/RTAUdio.h
-!linux:INCLUDEPATH += ../rtaudio
+macx:LIBS += -lrtaudio
linux:LIBS += -lpulse -lpulse-simple -lrtaudio -lpthread -ludev
win32:INCLUDEPATH += ../portaudio/include
@@ -107,8 +105,6 @@ win32:RC_ICONS = "resources/icons/Windows/wfview 512x512.ico"
macx{
ICON = resources/wfview.icns
- QMAKE_MACOSX_DEPLOYMENT_TARGET = 10.15
- QMAKE_APPLE_DEVICE_ARCHS = x86_64 arm64
MY_ENTITLEMENTS.name = CODE_SIGN_ENTITLEMENTS
MY_ENTITLEMENTS.value = resources/wfview.entitlements
QMAKE_MAC_XCODE_SETTINGS += MY_ENTITLEMENTS
@@ -120,8 +116,7 @@ macx{
QMAKE_TARGET_BUNDLE_PREFIX = org.wfview
-!win32:DEFINES += HOST=\\\"`hostname`\\\" UNAME=\\\"`whoami`\\\"
-!win32:DEFINES += GITSHORT="\\\"$(shell git -C \"$$PWD\" rev-parse --short HEAD)\\\""
+!win32:DEFINES += HOST=\\\"nixos\\\" UNAME=\\\"nix\\\" GITSHORT=\\\"0.0\\\"
win32:DEFINES += GITSHORT=\\\"$$system(git -C $$PWD rev-parse --short HEAD)\\\"
win32:DEFINES += HOST=\\\"$$system(hostname)\\\"
@@ -169,19 +164,8 @@ macx:LIBS += -framework CoreAudio -framework CoreFoundation -lpthread -lopus
CONFIG(debug, release|debug) {
- macos:LIBS += -L ../qcustomplot/qcustomplot-sharedlib/build -lqcustomplotd
-
- lessThan(QT_MAJOR_VERSION, 6) {
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libQCustomPlotd.so/ {print \"-lQCustomPlotd\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplotd2.so/ {print \"-lqcustomplotd2\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplotd.so/ {print \"-lqcustomplotd\"}'")
-
- } else {
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libQCustomPlotdQt6.so/ {print \"-lQCustomPlotdQt6\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplotd2qt6.so/ {print \"-lqcustomplotd2qt6\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplotdqt6.so/ {print \"-lqcustomplotdqt6\"}'")
- }
-
+ macos:LIBS += -lqcustomplotd
+ linux:LIBS += -lqcustomplotd
win32 {
contains(QMAKE_TARGET.arch, x86_64) {
LIBS += -L../opus/win32/VS2015/x64/DebugDLL/
@@ -211,17 +195,8 @@ CONFIG(debug, release|debug) {
}
} else {
- macos:LIBS += -L ../qcustomplot/qcustomplot-sharedlib/build -lqcustomplot
-
- lessThan(QT_MAJOR_VERSION, 6) {
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libQCustomPlot.so/ {print \"-lQCustomPlot\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplot2.so/ {print \"-lqcustomplot2\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplot.so/ {print \"-lqcustomplot\"}'")
- } else {
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libQCustomPlotQt6.so/ {print \"-lQCustomPlotQt6\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplot2qt6.so/ {print \"-lqcustomplot2qt6\"}'")
- linux:LIBS += $$system("/sbin/ldconfig -p | awk '/libqcustomplotqt6.so/ {print \"-lqcustomplotqt6\"}'")
- }
+ macos:LIBS += -lqcustomplot
+ linux:LIBS += -lqcustomplot
win32 {
contains(QMAKE_TARGET.arch, x86_64) {
LIBS += -L../opus/win32/VS2015/x64/ReleaseDLL/
@@ -264,9 +239,6 @@ win32:LIBS += -lopus -lole32 -luser32
#macx:HEADERS += ../qcustomplot/qcustomplot.h
win32:INCLUDEPATH += ../qcustomplot
-!linux:INCLUDEPATH += ../opus/include
-!linux:INCLUDEPATH += ../eigen
-!linux:INCLUDEPATH += ../r8brain-free-src
INCLUDEPATH += resampler
+9 -9
View File
@@ -1,20 +1,20 @@
{
"aarch64-darwin": {
"version": "1.8.2",
"version": "1.9.0",
"vscodeVersion": "1.99.1",
"url": "https://windsurf-stable.codeiumdata.com/darwin-arm64/stable/eccc45da0d0c40e57275e0cce7db644c7b1278d8/Windsurf-darwin-arm64-1.8.2.zip",
"sha256": "d1d353f6f78b570500546a1a1ee140d195df7497ce3eb946fb159afd0cc34a67"
"url": "https://windsurf-stable.codeiumdata.com/darwin-arm64/stable/fbebfca390b10f7a152fd231f94606109d576e12/Windsurf-darwin-arm64-1.9.0.zip",
"sha256": "44706f90321bdc4c2a2320a03c79fdd01c911236daa4cc675c597851974a268c"
},
"x86_64-darwin": {
"version": "1.8.2",
"version": "1.9.0",
"vscodeVersion": "1.99.1",
"url": "https://windsurf-stable.codeiumdata.com/darwin-x64/stable/eccc45da0d0c40e57275e0cce7db644c7b1278d8/Windsurf-darwin-x64-1.8.2.zip",
"sha256": "920ea85cdb98755eeadabf69fa2ed56baf24df7273aa28a1ad7b33f2d4acb862"
"url": "https://windsurf-stable.codeiumdata.com/darwin-x64/stable/fbebfca390b10f7a152fd231f94606109d576e12/Windsurf-darwin-x64-1.9.0.zip",
"sha256": "ae398d597cd143144c2bdc8bf0a853a1c57b6de2c86c95087a4be5db78252e75"
},
"x86_64-linux": {
"version": "1.8.2",
"version": "1.9.0",
"vscodeVersion": "1.99.1",
"url": "https://windsurf-stable.codeiumdata.com/linux-x64/stable/eccc45da0d0c40e57275e0cce7db644c7b1278d8/Windsurf-linux-x64-1.8.2.tar.gz",
"sha256": "677793a06575428d95e1ad73a0063580f116c9467c100ca0b218b6a89262ba2b"
"url": "https://windsurf-stable.codeiumdata.com/linux-x64/stable/fbebfca390b10f7a152fd231f94606109d576e12/Windsurf-linux-x64-1.9.0.tar.gz",
"sha256": "941640e3514a5ee524943135b439219243adb288fec484712ebc2935173aa938"
}
}
@@ -0,0 +1,23 @@
{
lib,
fetchFromGitHub,
mkYaziPlugin,
}:
mkYaziPlugin {
pname = "nord.yazi";
version = "0-unstable-2025-05-14";
src = fetchFromGitHub {
owner = "stepbrobd";
repo = "nord.yazi";
rev = "0f8eff4367021be1b741391d98853fbd1a34baf9";
hash = "sha256-bcYIbKFU1bvGRS6lgEBMe2jT13bECYgQATuh3QKmhQE=";
};
meta = {
description = "nordic yazi";
homepage = "https://github.com/stepbrobd/nord.yazi";
license = lib.licenses.mit;
maintainers = with lib.maintainers; [ stepbrobd ];
};
}
@@ -5,13 +5,13 @@
}:
mkYaziPlugin {
pname = "restore.yazi";
version = "25.2.7-unstable-2025-04-04";
version = "25.2.7-unstable-2025-04-24";
src = fetchFromGitHub {
owner = "boydaihungst";
repo = "restore.yazi";
rev = "328dd888c1e2b9b0cb5dc806f099e3164e179620";
hash = "sha256-3Z8P25u9bffdjrPjxLRWUQn6MdBS+vyElUBkgV4EUwY=";
rev = "539aad5077dc8b342a580036e416f2b949b6590e";
hash = "sha256-ngwbweKF7pSEpzy1TNzbKz8cFIWaDison5vCiGxkHFk=";
};
meta = {
@@ -3230,6 +3230,9 @@ self: super:
# 2025-04-19: Tests randomly fail 5 out of 10 times
fft = dontCheck super.fft;
# 2025-5-15: Too strict bounds on base <4.19, see: https://github.com/zachjs/sv2v/issues/317
sv2v = doJailbreak super.sv2v;
}
// import ./configuration-tensorflow.nix { inherit pkgs haskellLib; } self super
@@ -5935,7 +5935,6 @@ broken-packages:
- supplemented # failure in job https://hydra.nixos.org/build/233237397 at 2023-09-02
- supply-chain-core # failure in job https://hydra.nixos.org/build/252715612 at 2024-03-16
- surjective # failure in job https://hydra.nixos.org/build/233242908 at 2023-09-02
- sv2v # failure in job https://hydra.nixos.org/build/295097359 at 2025-04-22
- sv-core # failure in job https://hydra.nixos.org/build/233217245 at 2023-09-02
- SVD2HS # failure in job https://hydra.nixos.org/build/233248575 at 2023-09-02
- svfactor # failure in job https://hydra.nixos.org/build/233256743 at 2023-09-02
-2
View File
@@ -642669,9 +642669,7 @@ self: {
];
description = "SystemVerilog to Verilog conversion";
license = lib.licenses.bsd3;
hydraPlatforms = lib.platforms.none;
mainProgram = "sv2v";
broken = true;
}
) { };
@@ -0,0 +1,68 @@
{
stdenv,
lib,
fetchFromGitLab,
fetchurl,
fixDarwinDylibNames,
qtbase,
qmake,
}:
stdenv.mkDerivation (finalAttrs: {
pname = "qcustomplot";
version = "2.1.1";
srcs = [
(fetchFromGitLab {
owner = "ecme2";
repo = "QCustomPlot";
tag = "v${finalAttrs.version}";
hash = "sha256-BW8H/vDbhK3b8t8oB92icEBemzcdRdrIz2aKqlUi6UU=";
})
(fetchurl {
url = "https://www.qcustomplot.com/release/${finalAttrs.version}/QCustomPlot-source.tar.gz";
hash = "sha256-Xi0i3sd5248B81fL2yXlT7z5ca2u516ujXrSRESHGC8=";
})
];
sourceRoot = ".";
buildInputs = [ qtbase ];
nativeBuildInputs =
[
qmake
]
++ lib.optionals stdenv.hostPlatform.isDarwin [
fixDarwinDylibNames
];
env.LANG = "C.UTF-8";
qmakeFlags = [ "sharedlib/sharedlib-compilation/sharedlib-compilation.pro" ];
dontWrapQtApps = true;
postUnpack = ''
cp -rv source/* .
cp -rv qcustomplot-source/* .
'';
installPhase = ''
runHook preInstall
install -vDm 644 "qcustomplot.h" -t "$out/include/"
install -vdm 755 "$out/lib/"
cp -av libqcustomplot*${stdenv.hostPlatform.extensions.sharedLibrary}* "$out/lib/"
runHook postInstall
'';
meta = {
homepage = "https://qtcustomplot.com/";
description = "Qt C++ widget for plotting and data visualization";
license = lib.licenses.gpl3Plus;
platforms = lib.platforms.unix;
maintainers = with lib.maintainers; [ Cryolitia ];
};
})
@@ -359,7 +359,7 @@
buildPythonPackage rec {
pname = "boto3-stubs";
version = "1.38.13";
version = "1.38.16";
pyproject = true;
disabled = pythonOlder "3.7";
@@ -367,7 +367,7 @@ buildPythonPackage rec {
src = fetchPypi {
pname = "boto3_stubs";
inherit version;
hash = "sha256-j3OnRXRdXtOiBkJ/9GroLEjDf4bQ0mQ5WJi98OVWNSA=";
hash = "sha256-dZrhWJtN5u/rT0ehuEtObj536bNbT0bpqDTEmpEbfwQ=";
};
build-system = [ setuptools ];
@@ -10,7 +10,7 @@
buildPythonPackage rec {
pname = "botocore-stubs";
version = "1.38.13";
version = "1.38.16";
pyproject = true;
disabled = pythonOlder "3.7";
@@ -18,7 +18,7 @@ buildPythonPackage rec {
src = fetchPypi {
pname = "botocore_stubs";
inherit version;
hash = "sha256-x2bLqukcE3oc5RYGAfTMIzEuvWCece16Pbz2qJazs1A=";
hash = "sha256-SOxutsOJI9Dg+UlOcshpRiq1/9NXi5HNLZH9lNNh4Dw=";
};
nativeBuildInputs = [ setuptools ];
@@ -9,14 +9,14 @@
buildPythonPackage rec {
pname = "django-pglock";
version = "1.7.1";
version = "1.7.2";
pyproject = true;
src = fetchFromGitHub {
owner = "AmbitionEng";
repo = "django-pglock";
tag = version;
hash = "sha256-WbifapA2A0grxePozwDSPzREIzmgBV+V5wpA9jeYfJ8=";
hash = "sha256-FKAIftHNpfGzED0nkrLv3gVhfS7lyqfwZ1mEKsw/Vc8=";
};
build-system = [ poetry-core ];
@@ -31,7 +31,7 @@ buildPythonPackage rec {
meta = {
description = "Postgres advisory locks, table locks, and blocking lock management";
homepage = "https://github.com/AmbitionEng/django-pglock";
changelog = "https://github.com/AmbitionEng/django-pglock/blob/${version}/CHANGELOG.md";
changelog = "https://github.com/AmbitionEng/django-pglock/blob/${src.tag}/CHANGELOG.md";
license = lib.licenses.bsd3;
maintainers = with lib.maintainers; [ jopejoe1 ];
};
@@ -314,8 +314,8 @@ rec {
"sha256-Uek62hNK0eJRxRj9YiU4R44w33IUyrXZ9AyGbEcoiyc=";
mypy-boto3-cognito-idp =
buildMypyBoto3Package "cognito-idp" "1.38.0"
"sha256-ytRI2TYHsl90U3QtD1k8QVhsd5ILcJB3YjWLIVf7qH8=";
buildMypyBoto3Package "cognito-idp" "1.38.16"
"sha256-2IExKWR4xOJkI+HHJMemU88PoBsi5lzkTq03cUhFLv0=";
mypy-boto3-cognito-sync =
buildMypyBoto3Package "cognito-sync" "1.38.0"
@@ -358,8 +358,8 @@ rec {
"sha256-ABRIC59mat4ek0yrWxcHUr62whXmaZef47yDR7A2rl0=";
mypy-boto3-controltower =
buildMypyBoto3Package "controltower" "1.38.0"
"sha256-3yIoiaPmgYBOTCYk2RQyHWyhUlA0qZXUfLnhKESeUWU=";
buildMypyBoto3Package "controltower" "1.38.15"
"sha256-UdmjmkHw97cpq6vDS6d48a3DOLkZ/RJATTH8DxfhFpY=";
mypy-boto3-cur =
buildMypyBoto3Package "cur" "1.38.0"
@@ -446,8 +446,8 @@ rec {
"sha256-RQh46jrXqj4bXTRJ+tPR9sql7yUn7Ek9u4p0OU0A7b0=";
mypy-boto3-ec2 =
buildMypyBoto3Package "ec2" "1.38.12"
"sha256-NpOkYFCgUxUbk6SJXYWYN5/FMGs8aIzBVe/NhkLUoR0=";
buildMypyBoto3Package "ec2" "1.38.14"
"sha256-+EI+0aGCa21XL3qoAr821F/j8dJTCaLcVRKP743szUQ=";
mypy-boto3-ec2-instance-connect =
buildMypyBoto3Package "ec2-instance-connect" "1.38.0"
@@ -462,8 +462,8 @@ rec {
"sha256-aSZu8mxsTho4pvWWbNwlJf0IROjqjTlIUEE5DJkAje4=";
mypy-boto3-ecs =
buildMypyBoto3Package "ecs" "1.38.9"
"sha256-LxgLG+uNpChV9MZ/9xsF5RayVU5i2qjYp73jAQFBA6s=";
buildMypyBoto3Package "ecs" "1.38.15"
"sha256-2SM1EqTNnvyNEUbeTz9RmG3CsOfkQ3enuvQFOH2je8A=";
mypy-boto3-efs =
buildMypyBoto3Package "efs" "1.38.0"
@@ -534,8 +534,8 @@ rec {
"sha256-0Ln8pT0rhaR4xXe4gLPKQWuzuq2WJ1IyhvpUf3YKehM=";
mypy-boto3-firehose =
buildMypyBoto3Package "firehose" "1.38.0"
"sha256-mmOpANvBTUTilWXZ8h5tMTwffEawd6HwVBJppLe1Z74=";
buildMypyBoto3Package "firehose" "1.38.16"
"sha256-IL9bOLR3F7TMmJr/MUVBAQVOmZ8Bp/1cWOvMxEFzbUU=";
mypy-boto3-fis =
buildMypyBoto3Package "fis" "1.38.0"
@@ -606,8 +606,8 @@ rec {
"sha256-z839V1DLHxIkZrSjzWpLbAMGszL3UokIHAHwaVFhSDQ=";
mypy-boto3-iam =
buildMypyBoto3Package "iam" "1.38.0"
"sha256-Lh1EnEdDGQEWHNDQiDX5x08oF+TbzTd5IunMwYTqUs4=";
buildMypyBoto3Package "iam" "1.38.14"
"sha256-RpIgAHS/kX2nySN7LFC7uXGJMcn5m3PleezdEAtlgqM=";
mypy-boto3-identitystore =
buildMypyBoto3Package "identitystore" "1.38.0"
@@ -790,8 +790,8 @@ rec {
"sha256-hHMZReLH2J2vgdkECWREXAp/2ZOoJSynZU8epapC188=";
mypy-boto3-license-manager =
buildMypyBoto3Package "license-manager" "1.38.0"
"sha256-jDFm+V7sTX+oQeWt8aiW4yN2HeXz8fSu9ZjIn/vNoig=";
buildMypyBoto3Package "license-manager" "1.38.15"
"sha256-2zkjzEgJC9wzLiCTUU5XB3YXcX2OVeb8oOvpI/ITiaQ=";
mypy-boto3-license-manager-linux-subscriptions =
buildMypyBoto3Package "license-manager-linux-subscriptions" "1.38.0"
@@ -810,8 +810,8 @@ rec {
"sha256-uypKW3Cqj98SLeWmSwCXVKhKpXWXEvwdUexqqFgXeEc=";
mypy-boto3-logs =
buildMypyBoto3Package "logs" "1.38.13"
"sha256-VOkEcgDn4G1v1DB/Berg5yP+PYUf7YBfQ+T4yvATVBs=";
buildMypyBoto3Package "logs" "1.38.16"
"sha256-TE/PCNUYLj55t7JbGdv0UZ3OUvx0IgpYrL5b22KEnfM=";
mypy-boto3-lookoutequipment =
buildMypyBoto3Package "lookoutequipment" "1.38.0"
@@ -862,12 +862,12 @@ rec {
"sha256-F6Yv7tgHnzgsekH7HJ8s7/Kpq1JiZkHs+qZEez5snUI=";
mypy-boto3-mediaconvert =
buildMypyBoto3Package "mediaconvert" "1.38.9"
"sha256-n6yMEzEVwlorfkyPVf3wYsNjbTVvujEd6GR/SRPTCOk=";
buildMypyBoto3Package "mediaconvert" "1.38.16"
"sha256-13hTO6ZkJl+6IuEjJFl4Yy0McVURcRxfeefzgPnrULs=";
mypy-boto3-medialive =
buildMypyBoto3Package "medialive" "1.38.11"
"sha256-K0EgOaQKgTAoVlbPqc90j44OI+6YeHUEDe20hWjnyQQ=";
buildMypyBoto3Package "medialive" "1.38.14"
"sha256-AG2+2CVchluScgVnd8sPU3EpVyDcSmJ3HXxFVlU66Yw=";
mypy-boto3-mediapackage =
buildMypyBoto3Package "mediapackage" "1.38.0"
@@ -890,8 +890,8 @@ rec {
"sha256-OyelTdU5Rwh1zsYfbRZ6t+pJNt4y3S96U2KJEqrIdsk=";
mypy-boto3-mediatailor =
buildMypyBoto3Package "mediatailor" "1.38.0"
"sha256-LjWG40uhYRU6qpuTH4Vw8XUjzhv+CN5PhuV+CPu0sjc=";
buildMypyBoto3Package "mediatailor" "1.38.14"
"sha256-mhgPrqIp5UdrI+zhEXjmYQbBjyeX8vuiWhwg8tSfo+w=";
mypy-boto3-medical-imaging =
buildMypyBoto3Package "medical-imaging" "1.38.0"
@@ -1166,16 +1166,16 @@ rec {
"sha256-+P5YbkUSP/zTBaDDCEcSjzkx2IhknitMWlL0Ehg8hAo=";
mypy-boto3-s3control =
buildMypyBoto3Package "s3control" "1.38.0"
"sha256-KsxNSyn593BuTjScIt0Mo7oUGhUX150wi/oIDnAx+9I=";
buildMypyBoto3Package "s3control" "1.38.14"
"sha256-vCG6YvEf2ncO6cyqWW56LVXMh4dLzfz6uQAT50xzeuE=";
mypy-boto3-s3outposts =
buildMypyBoto3Package "s3outposts" "1.38.0"
"sha256-lBWZesgIKYnjSjUOPBhF4GNsNSk09YDSEyX0qweT3iM=";
mypy-boto3-sagemaker =
buildMypyBoto3Package "sagemaker" "1.38.11"
"sha256-jImugcJSB+LIaZsUBTyuI9yN3+D8Gw49l5j78VK4Now=";
buildMypyBoto3Package "sagemaker" "1.38.14"
"sha256-XKVR3rpjs3qNWapIjo28h2D5CywnrBYi8dEbkCtzRhg=";
mypy-boto3-sagemaker-a2i-runtime =
buildMypyBoto3Package "sagemaker-a2i-runtime" "1.38.0"
@@ -16,7 +16,7 @@
buildPythonPackage rec {
pname = "nbxmpp";
version = "6.1.1";
version = "6.2.0";
format = "pyproject";
disabled = pythonOlder "3.10";
@@ -26,7 +26,7 @@ buildPythonPackage rec {
owner = "gajim";
repo = "python-nbxmpp";
rev = "refs/tags/${version}";
hash = "sha256-zuPaQCBXJl515MFSfJ2Y9cQtVccDGGSQzpZn3DTSa3Q=";
hash = "sha256-BaRLYuyn0acikX0Imsul2yY+w4jdtXTlE84hAovuZ/4=";
};
nativeBuildInputs = [
@@ -31,10 +31,10 @@ let
defaultVersion = lib.switch rocq-core.rocq-version [
{
case = "9.0";
out = "2.5.1";
out = "2.5.2";
}
] null;
release."2.5.1".sha256 = "sha256-vw18iPPoI44tM8C05Wj4YvFAi1jjfyjZ90dbxX4NgQM=";
release."2.5.2".sha256 = "sha256-lLzjPrbVB3rrqox528YiheUb0u89R84Xmrgkn0oplOs=";
releaseRev = v: "v${v}";
mlPlugin = true;
+4 -4
View File
@@ -59,14 +59,14 @@ let
in
{
nextcloud30 = generic {
version = "30.0.10";
hash = "sha256-40ldF8X1yRZFQtk/Y21pasyPOLYL7HDPGtLnnHbZlbo=";
version = "30.0.11";
hash = "sha256-WEJ3LV1xLxBdyPFdZ4hFnmFEuDbMiKBiyQU3CiZUN3o=";
packages = nextcloud30Packages;
};
nextcloud31 = generic {
version = "31.0.4";
hash = "sha256-pHVBVm1casb2Pk9hfifaKVFW2kfaos0i7uNAD9KtElE=";
version = "31.0.5";
hash = "sha256-Iii49STc2H8IoqkoHUGwT1y1ALdiS8jI4HuOMDkGFQM=";
packages = nextcloud31Packages;
};
+30 -30
View File
@@ -20,9 +20,9 @@
]
},
"calendar": {
"hash": "sha256-tzlJJsP3uDA57LuOtfbYjd5yu2fkEunTqDM90LxVgnI=",
"url": "https://github.com/nextcloud-releases/calendar/releases/download/v5.2.1/calendar-v5.2.1.tar.gz",
"version": "5.2.1",
"hash": "sha256-z/BMKay9Fj+aIypPA9cbEJ6dcB03oGPhy2TSGHJeRz0=",
"url": "https://github.com/nextcloud-releases/calendar/releases/download/v5.2.4/calendar-v5.2.4.tar.gz",
"version": "5.2.4",
"description": "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite teams matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **Were not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries.",
"homepage": "https://github.com/nextcloud/calendar/",
"licenses": [
@@ -30,9 +30,9 @@
]
},
"collectives": {
"hash": "sha256-1BEK5T+6w8yLSXyj/Me8QMls/LSWaor5TpvC2HK3/4U=",
"url": "https://github.com/nextcloud/collectives/releases/download/v2.16.1/collectives-2.16.1.tar.gz",
"version": "2.16.1",
"hash": "sha256-U6EQumuN7b309JtaWwdbluQcK7Gpt5O6q9fJu6qyVhE=",
"url": "https://github.com/nextcloud/collectives/releases/download/v2.17.0/collectives-2.17.0.tar.gz",
"version": "2.17.0",
"description": "Collectives is a Nextcloud App for activist and community projects to organize together.\nCome and gather in collectives to build shared knowledge.\n\n* 👥 **Collective and non-hierarchical workflow by heart**: Collectives are\n tied to a [Nextcloud Team](https://github.com/nextcloud/circles) and\n owned by the collective.\n* 📝 **Collaborative page editing** like known from Etherpad thanks to the\n [Text app](https://github.com/nextcloud/text).\n* 🔤 **Well-known [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax**\n for page formatting.\n\n## Installation\n\nIn your Nextcloud instance, simply navigate to **»Apps«**, find the\n**»Teams«** and **»Collectives«** apps and enable them.",
"homepage": "https://github.com/nextcloud/collectives",
"licenses": [
@@ -40,9 +40,9 @@
]
},
"contacts": {
"hash": "sha256-3G1di/PnOAIML2vwKglmuMApvn8+nXYjdqnySSSoLDI=",
"url": "https://github.com/nextcloud-releases/contacts/releases/download/v7.0.6/contacts-v7.0.6.tar.gz",
"version": "7.0.6",
"hash": "sha256-OYObGIEAViBMWesL/kNv4FHO7SSa73rdVjklwuyPSrY=",
"url": "https://github.com/nextcloud-releases/contacts/releases/download/v7.1.0/contacts-v7.1.0.tar.gz",
"version": "7.1.0",
"description": "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **Were not reinventing the wheel!** Based on the great and open SabreDAV library.",
"homepage": "https://github.com/nextcloud/contacts#readme",
"licenses": [
@@ -70,9 +70,9 @@
]
},
"deck": {
"hash": "sha256-Rb8VSCy/jL9U02mh2FBBK45nahMU6A90BFtKlLs4nNI=",
"url": "https://github.com/nextcloud-releases/deck/releases/download/v1.14.4/deck-v1.14.4.tar.gz",
"version": "1.14.4",
"hash": "sha256-A2n68T7x4la4VrMwsBMIWk6LWM4nge9FtQhl5eLp8jQ=",
"url": "https://github.com/nextcloud-releases/deck/releases/download/v1.14.5/deck-v1.14.5.tar.gz",
"version": "1.14.5",
"description": "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized",
"homepage": "https://github.com/nextcloud/deck",
"licenses": [
@@ -110,9 +110,9 @@
]
},
"files_retention": {
"hash": "sha256-krJOb925AjmnwmkFYg00eC4KmICr4Tf3jUANYWTRJdA=",
"url": "https://github.com/nextcloud-releases/files_retention/releases/download/v1.19.0/files_retention-v1.19.0.tar.gz",
"version": "1.19.0",
"hash": "sha256-1Ga6l+k+QWyFxcR65Zf9aCXgIe6uSAwofTcsCvFN530=",
"url": "https://github.com/nextcloud-releases/files_retention/releases/download/v1.19.1/files_retention-v1.19.1.tar.gz",
"version": "1.19.1",
"description": "An app for Nextcloud to control automatic deletion of files after a given time.\nOptionally the users can be informed the day before.",
"homepage": "https://github.com/nextcloud/files_retention",
"licenses": [
@@ -190,18 +190,18 @@
]
},
"mail": {
"hash": "sha256-AV0vrDU4zeg7AQQpJkj5mHQatxCa2RMON5tY4Q/OjyM=",
"url": "https://github.com/nextcloud-releases/mail/releases/download/v5.0.0/mail-v5.0.0.tar.gz",
"version": "5.0.0",
"description": "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 Were not reinventing the wheel!** Based on the great [Horde](https://horde.org) libraries.\n- **📬 Want to host your own mail server?** We do not have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!\n\n## Ethical AI Rating\n\n### Priority Inbox\n\nPositive:\n* The software for training and inferencing of this model is open source.\n* The model is created and trained on-premises based on the user's own data.\n* The training data is accessible to the user, making it possible to check or correct for bias or optimise the performance and CO2 usage.\n\n### Thread Summaries (opt-in)\n\n**Rating:** 🟢/🟡/🟠/🔴\n\nThe rating depends on the installed text processing backend. See [the rating overview](https://docs.nextcloud.com/server/latest/admin_manual/ai/index.html) for details.\n\nLearn more about the Nextcloud Ethical AI Rating [in our blog](https://nextcloud.com/blog/nextcloud-ethical-ai-rating/).",
"hash": "sha256-uDig7ySWlx7WqYzjB9H45p3a9EfUFxY3Es0dso6uQJs=",
"url": "https://github.com/nextcloud-releases/mail/releases/download/v5.0.7/mail-v5.0.7.tar.gz",
"version": "5.0.7",
"description": "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 Were not reinventing the wheel!** Based on the great [Horde](https://www.horde.org) libraries.\n- **📬 Want to host your own mail server?** We do not have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!\n\n## Ethical AI Rating\n\n### Priority Inbox\n\nPositive:\n* The software for training and inferencing of this model is open source.\n* The model is created and trained on-premises based on the user's own data.\n* The training data is accessible to the user, making it possible to check or correct for bias or optimise the performance and CO2 usage.\n\n### Thread Summaries (opt-in)\n\n**Rating:** 🟢/🟡/🟠/🔴\n\nThe rating depends on the installed text processing backend. See [the rating overview](https://docs.nextcloud.com/server/latest/admin_manual/ai/index.html) for details.\n\nLearn more about the Nextcloud Ethical AI Rating [in our blog](https://nextcloud.com/blog/nextcloud-ethical-ai-rating/).",
"homepage": "https://github.com/nextcloud/mail#readme",
"licenses": [
"agpl"
]
},
"maps": {
"hash": "sha256-/uoM29jXqeOvOJBu3xhv+KgqPE7T03pV269fdr2Er+0=",
"url": "https://github.com/nextcloud/maps/releases/download/v1.6.0-2-nightly/maps-1.6.0-2-nightly.tar.gz",
"hash": "sha256-E0S/CwXyye19lcuiONEQCyHJqlL0ZG1A9Q7oOTEZH1g=",
"url": "https://github.com/nextcloud/maps/releases/download/v1.6.0-3-nightly/maps-1.6.0-3-nightly.tar.gz",
"version": "1.6.0",
"description": "**The whole world fits inside your cloud!**\n\n- **🗺 Beautiful map:** Using [OpenStreetMap](https://www.openstreetmap.org) and [Leaflet](https://leafletjs.com), you can choose between standard map, satellite, topographical, dark mode or even watercolor! 🎨\n- **⭐ Favorites:** Save your favorite places, privately! Sync with [GNOME Maps](https://github.com/nextcloud/maps/issues/30) and mobile apps is planned.\n- **🧭 Routing:** Possible using either [OSRM](http://project-osrm.org), [GraphHopper](https://www.graphhopper.com) or [Mapbox](https://www.mapbox.com).\n- **🖼 Photos on the map:** No more boring slideshows, just show directly where you were!\n- **🙋 Contacts on the map:** See where your friends live and plan your next visit.\n- **📱 Devices:** Lost your phone? Check the map!\n- **〰 Tracks:** Load GPS tracks or past trips. Recording with [PhoneTrack](https://f-droid.org/en/packages/net.eneiluj.nextcloud.phonetrack/) or [OwnTracks](https://owntracks.org) is planned.",
"homepage": "https://github.com/nextcloud/maps",
@@ -330,9 +330,9 @@
]
},
"richdocuments": {
"hash": "sha256-4J4tEwwVjSUgJa6A1Luz8u0x8wjlkA6nukaqtt1VOZc=",
"url": "https://github.com/nextcloud-releases/richdocuments/releases/download/v8.5.6/richdocuments-v8.5.6.tar.gz",
"version": "8.5.6",
"hash": "sha256-vvZZE76NLNgrqwufVV/FVp09W8udJvY6iWzxxMuLCU0=",
"url": "https://github.com/nextcloud-releases/richdocuments/releases/download/v8.5.7/richdocuments-v8.5.7.tar.gz",
"version": "8.5.7",
"description": "This application can connect to a Collabora Online (or other) server (WOPI-like Client). Nextcloud is the WOPI Host. Please read the documentation to learn more about that.\n\nYou can also edit your documents off-line with the Collabora Office app from the **[Android](https://play.google.com/store/apps/details?id=com.collabora.libreoffice)** and **[iOS](https://apps.apple.com/us/app/collabora-office/id1440482071)** store.",
"homepage": "https://collaboraoffice.com/",
"licenses": [
@@ -420,9 +420,9 @@
]
},
"user_oidc": {
"hash": "sha256-qEsUJG63j+VRZc+tqeX4iTEs9/GIVsTsyeFEOwSBYCg=",
"url": "https://github.com/nextcloud-releases/user_oidc/releases/download/v7.1.0/user_oidc-v7.1.0.tar.gz",
"version": "7.1.0",
"hash": "sha256-nXDWfRP9n9eH+JGg1a++kD5uLMsXh5BHAaTAOgLI9W4=",
"url": "https://github.com/nextcloud-releases/user_oidc/releases/download/v7.2.0/user_oidc-v7.2.0.tar.gz",
"version": "7.2.0",
"description": "Allows flexible configuration of an OIDC server as Nextcloud login user backend.",
"homepage": "https://github.com/nextcloud/user_oidc",
"licenses": [
@@ -430,9 +430,9 @@
]
},
"user_saml": {
"hash": "sha256-i9V8fmmmed0rVKRNtYJysqJReuGPjE54GP5K5wN0+Ok=",
"url": "https://github.com/nextcloud-releases/user_saml/releases/download/v6.5.0/user_saml-v6.5.0.tar.gz",
"version": "6.5.0",
"hash": "sha256-MS1+fiDTufQXtKCG/45B2hQEfAVbsZb+TZb74f4EvAE=",
"url": "https://github.com/nextcloud-releases/user_saml/releases/download/v6.6.0/user_saml-v6.6.0.tar.gz",
"version": "6.6.0",
"description": "Using the SSO & SAML app of your Nextcloud you can make it easily possible to integrate your existing Single-Sign-On solution with Nextcloud. In addition, you can use the Nextcloud LDAP user provider to keep the convenience for users. (e.g. when sharing)\nThe following providers are supported and tested at the moment:\n\n* **SAML 2.0**\n\t* OneLogin\n\t* Shibboleth\n\t* Active Directory Federation Services (ADFS)\n\n* **Authentication via Environment Variable**\n\t* Kerberos (mod_auth_kerb)\n\t* Any other provider that authenticates using the environment variable\n\nWhile theoretically any other authentication provider implementing either one of those standards is compatible, we like to note that they are not part of any internal test matrix.",
"homepage": "https://github.com/nextcloud/user_saml",
"licenses": [
+41 -31
View File
@@ -20,9 +20,9 @@
]
},
"calendar": {
"hash": "sha256-tzlJJsP3uDA57LuOtfbYjd5yu2fkEunTqDM90LxVgnI=",
"url": "https://github.com/nextcloud-releases/calendar/releases/download/v5.2.1/calendar-v5.2.1.tar.gz",
"version": "5.2.1",
"hash": "sha256-z/BMKay9Fj+aIypPA9cbEJ6dcB03oGPhy2TSGHJeRz0=",
"url": "https://github.com/nextcloud-releases/calendar/releases/download/v5.2.4/calendar-v5.2.4.tar.gz",
"version": "5.2.4",
"description": "The Calendar app is a user interface for Nextcloud's CalDAV server. Easily sync events from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Contacts - more to come.\n* 🌐 **WebCal Support!** Want to see your favorite teams matchdays in your calendar? No problem!\n* 🙋 **Attendees!** Invite people to your events\n* ⌚️ **Free/Busy!** See when your attendees are available to meet\n* ⏰ **Reminders!** Get alarms for events inside your browser and via email\n* 🔍 Search! Find your events at ease\n* ☑️ Tasks! See tasks with a due date directly in the calendar\n* 🙈 **Were not reinventing the wheel!** Based on the great [c-dav library](https://github.com/nextcloud/cdav-library), [ical.js](https://github.com/mozilla-comm/ical.js) and [fullcalendar](https://github.com/fullcalendar/fullcalendar) libraries.",
"homepage": "https://github.com/nextcloud/calendar/",
"licenses": [
@@ -30,9 +30,9 @@
]
},
"collectives": {
"hash": "sha256-1BEK5T+6w8yLSXyj/Me8QMls/LSWaor5TpvC2HK3/4U=",
"url": "https://github.com/nextcloud/collectives/releases/download/v2.16.1/collectives-2.16.1.tar.gz",
"version": "2.16.1",
"hash": "sha256-U6EQumuN7b309JtaWwdbluQcK7Gpt5O6q9fJu6qyVhE=",
"url": "https://github.com/nextcloud/collectives/releases/download/v2.17.0/collectives-2.17.0.tar.gz",
"version": "2.17.0",
"description": "Collectives is a Nextcloud App for activist and community projects to organize together.\nCome and gather in collectives to build shared knowledge.\n\n* 👥 **Collective and non-hierarchical workflow by heart**: Collectives are\n tied to a [Nextcloud Team](https://github.com/nextcloud/circles) and\n owned by the collective.\n* 📝 **Collaborative page editing** like known from Etherpad thanks to the\n [Text app](https://github.com/nextcloud/text).\n* 🔤 **Well-known [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax**\n for page formatting.\n\n## Installation\n\nIn your Nextcloud instance, simply navigate to **»Apps«**, find the\n**»Teams«** and **»Collectives«** apps and enable them.",
"homepage": "https://github.com/nextcloud/collectives",
"licenses": [
@@ -40,9 +40,9 @@
]
},
"contacts": {
"hash": "sha256-3G1di/PnOAIML2vwKglmuMApvn8+nXYjdqnySSSoLDI=",
"url": "https://github.com/nextcloud-releases/contacts/releases/download/v7.0.6/contacts-v7.0.6.tar.gz",
"version": "7.0.6",
"hash": "sha256-OYObGIEAViBMWesL/kNv4FHO7SSa73rdVjklwuyPSrY=",
"url": "https://github.com/nextcloud-releases/contacts/releases/download/v7.1.0/contacts-v7.1.0.tar.gz",
"version": "7.1.0",
"description": "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **Were not reinventing the wheel!** Based on the great and open SabreDAV library.",
"homepage": "https://github.com/nextcloud/contacts#readme",
"licenses": [
@@ -70,9 +70,9 @@
]
},
"deck": {
"hash": "sha256-MDh3g8K6xnJ9fgPzOR3BnDdzlVGbU3uvloirVI+970A=",
"url": "https://github.com/nextcloud-releases/deck/releases/download/v1.15.0/deck-v1.15.0.tar.gz",
"version": "1.15.0",
"hash": "sha256-VUdHoLYyCg7DsNu2LYZelmcHM4B0cfkH8PwcTK844mo=",
"url": "https://github.com/nextcloud-releases/deck/releases/download/v1.15.1/deck-v1.15.1.tar.gz",
"version": "1.15.1",
"description": "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in Markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your Markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized",
"homepage": "https://github.com/nextcloud/deck",
"licenses": [
@@ -110,9 +110,9 @@
]
},
"files_retention": {
"hash": "sha256-CwwYfezQUWhNkc7VpGkY+gJQTxEdtPnhxFAAQKkkaSM=",
"url": "https://github.com/nextcloud-releases/files_retention/releases/download/v2.0.0/files_retention-v2.0.0.tar.gz",
"version": "2.0.0",
"hash": "sha256-XsfqryUxaevIjUK5rE97UEMK2vm2J5cYCMM3RUU0SaI=",
"url": "https://github.com/nextcloud-releases/files_retention/releases/download/v2.0.1/files_retention-v2.0.1.tar.gz",
"version": "2.0.1",
"description": "An app for Nextcloud to control automatic deletion of files after a given time.\nOptionally the users can be informed the day before.",
"homepage": "https://github.com/nextcloud/files_retention",
"licenses": [
@@ -190,15 +190,25 @@
]
},
"mail": {
"hash": "sha256-AV0vrDU4zeg7AQQpJkj5mHQatxCa2RMON5tY4Q/OjyM=",
"url": "https://github.com/nextcloud-releases/mail/releases/download/v5.0.0/mail-v5.0.0.tar.gz",
"version": "5.0.0",
"description": "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 Were not reinventing the wheel!** Based on the great [Horde](https://horde.org) libraries.\n- **📬 Want to host your own mail server?** We do not have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!\n\n## Ethical AI Rating\n\n### Priority Inbox\n\nPositive:\n* The software for training and inferencing of this model is open source.\n* The model is created and trained on-premises based on the user's own data.\n* The training data is accessible to the user, making it possible to check or correct for bias or optimise the performance and CO2 usage.\n\n### Thread Summaries (opt-in)\n\n**Rating:** 🟢/🟡/🟠/🔴\n\nThe rating depends on the installed text processing backend. See [the rating overview](https://docs.nextcloud.com/server/latest/admin_manual/ai/index.html) for details.\n\nLearn more about the Nextcloud Ethical AI Rating [in our blog](https://nextcloud.com/blog/nextcloud-ethical-ai-rating/).",
"hash": "sha256-uDig7ySWlx7WqYzjB9H45p3a9EfUFxY3Es0dso6uQJs=",
"url": "https://github.com/nextcloud-releases/mail/releases/download/v5.0.7/mail-v5.0.7.tar.gz",
"version": "5.0.7",
"description": "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 Were not reinventing the wheel!** Based on the great [Horde](https://www.horde.org) libraries.\n- **📬 Want to host your own mail server?** We do not have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!\n\n## Ethical AI Rating\n\n### Priority Inbox\n\nPositive:\n* The software for training and inferencing of this model is open source.\n* The model is created and trained on-premises based on the user's own data.\n* The training data is accessible to the user, making it possible to check or correct for bias or optimise the performance and CO2 usage.\n\n### Thread Summaries (opt-in)\n\n**Rating:** 🟢/🟡/🟠/🔴\n\nThe rating depends on the installed text processing backend. See [the rating overview](https://docs.nextcloud.com/server/latest/admin_manual/ai/index.html) for details.\n\nLearn more about the Nextcloud Ethical AI Rating [in our blog](https://nextcloud.com/blog/nextcloud-ethical-ai-rating/).",
"homepage": "https://github.com/nextcloud/mail#readme",
"licenses": [
"agpl"
]
},
"maps": {
"hash": "sha256-E0S/CwXyye19lcuiONEQCyHJqlL0ZG1A9Q7oOTEZH1g=",
"url": "https://github.com/nextcloud/maps/releases/download/v1.6.0-3-nightly/maps-1.6.0-3-nightly.tar.gz",
"version": "1.6.0",
"description": "**The whole world fits inside your cloud!**\n\n- **🗺 Beautiful map:** Using [OpenStreetMap](https://www.openstreetmap.org) and [Leaflet](https://leafletjs.com), you can choose between standard map, satellite, topographical, dark mode or even watercolor! 🎨\n- **⭐ Favorites:** Save your favorite places, privately! Sync with [GNOME Maps](https://github.com/nextcloud/maps/issues/30) and mobile apps is planned.\n- **🧭 Routing:** Possible using either [OSRM](http://project-osrm.org), [GraphHopper](https://www.graphhopper.com) or [Mapbox](https://www.mapbox.com).\n- **🖼 Photos on the map:** No more boring slideshows, just show directly where you were!\n- **🙋 Contacts on the map:** See where your friends live and plan your next visit.\n- **📱 Devices:** Lost your phone? Check the map!\n- **〰 Tracks:** Load GPS tracks or past trips. Recording with [PhoneTrack](https://f-droid.org/en/packages/net.eneiluj.nextcloud.phonetrack/) or [OwnTracks](https://owntracks.org) is planned.",
"homepage": "https://github.com/nextcloud/maps",
"licenses": [
"agpl"
]
},
"memories": {
"hash": "sha256-BfxJDCGsiRJrZWkNJSQF3rSFm/G3zzQn7C6DCETSzw4=",
"url": "https://github.com/pulsejet/memories/releases/download/v7.5.2/memories.tar.gz",
@@ -320,9 +330,9 @@
]
},
"richdocuments": {
"hash": "sha256-jwwp3nnHxxO31dNwfv4OG6sPmTO2VmnFzNxylMVNVYo=",
"url": "https://github.com/nextcloud-releases/richdocuments/releases/download/v8.6.4/richdocuments-v8.6.4.tar.gz",
"version": "8.6.4",
"hash": "sha256-fxVopw6n+0wU+OMiR3QFw1c/8YrzVMTtFfRharvNl0A=",
"url": "https://github.com/nextcloud-releases/richdocuments/releases/download/v8.6.5/richdocuments-v8.6.5.tar.gz",
"version": "8.6.5",
"description": "This application can connect to a Collabora Online (or other) server (WOPI-like Client). Nextcloud is the WOPI Host. Please read the documentation to learn more about that.\n\nYou can also edit your documents off-line with the Collabora Office app from the **[Android](https://play.google.com/store/apps/details?id=com.collabora.libreoffice)** and **[iOS](https://apps.apple.com/us/app/collabora-office/id1440482071)** store.",
"homepage": "https://collaboraoffice.com/",
"licenses": [
@@ -340,9 +350,9 @@
]
},
"spreed": {
"hash": "sha256-lNct7bAJ7uyucSUvBwcDf3lPJiKx3N2k7+fi5Y5xLqg=",
"url": "https://github.com/nextcloud-releases/spreed/releases/download/v21.0.2/spreed-v21.0.2.tar.gz",
"version": "21.0.2",
"hash": "sha256-O0W1olbpau+GjYdND/IYMl3GJntsG9p51VRbmRWksTI=",
"url": "https://github.com/nextcloud-releases/spreed/releases/download/v21.0.4/spreed-v21.0.4.tar.gz",
"version": "21.0.4",
"description": "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa.",
"homepage": "https://github.com/nextcloud/spreed",
"licenses": [
@@ -400,9 +410,9 @@
]
},
"user_oidc": {
"hash": "sha256-qEsUJG63j+VRZc+tqeX4iTEs9/GIVsTsyeFEOwSBYCg=",
"url": "https://github.com/nextcloud-releases/user_oidc/releases/download/v7.1.0/user_oidc-v7.1.0.tar.gz",
"version": "7.1.0",
"hash": "sha256-nXDWfRP9n9eH+JGg1a++kD5uLMsXh5BHAaTAOgLI9W4=",
"url": "https://github.com/nextcloud-releases/user_oidc/releases/download/v7.2.0/user_oidc-v7.2.0.tar.gz",
"version": "7.2.0",
"description": "Allows flexible configuration of an OIDC server as Nextcloud login user backend.",
"homepage": "https://github.com/nextcloud/user_oidc",
"licenses": [
@@ -410,9 +420,9 @@
]
},
"user_saml": {
"hash": "sha256-i9V8fmmmed0rVKRNtYJysqJReuGPjE54GP5K5wN0+Ok=",
"url": "https://github.com/nextcloud-releases/user_saml/releases/download/v6.5.0/user_saml-v6.5.0.tar.gz",
"version": "6.5.0",
"hash": "sha256-MS1+fiDTufQXtKCG/45B2hQEfAVbsZb+TZb74f4EvAE=",
"url": "https://github.com/nextcloud-releases/user_saml/releases/download/v6.6.0/user_saml-v6.6.0.tar.gz",
"version": "6.6.0",
"description": "Using the SSO & SAML app of your Nextcloud you can make it easily possible to integrate your existing Single-Sign-On solution with Nextcloud. In addition, you can use the Nextcloud LDAP user provider to keep the convenience for users. (e.g. when sharing)\nThe following providers are supported and tested at the moment:\n\n* **SAML 2.0**\n\t* OneLogin\n\t* Shibboleth\n\t* Active Directory Federation Services (ADFS)\n\n* **Authentication via Environment Variable**\n\t* Kerberos (mod_auth_kerb)\n\t* Any other provider that authenticates using the environment variable\n\nWhile theoretically any other authentication provider implementing either one of those standards is compatible, we like to note that they are not part of any internal test matrix.",
"homepage": "https://github.com/nextcloud/user_saml",
"licenses": [
@@ -40,8 +40,6 @@ stdenv.mkDerivation (finalAttrs: {
"SPIFFS_VERSION=unknown"
];
doCheck = stdenv.buildPlatform.canExecute stdenv.hostPlatform;
installPhase = ''
install -Dm755 -t $out/bin mkspiffs
'';

Some files were not shown because too many files have changed in this diff Show More
diff --git a/admin/python-config-ldflags.py b/admin/python-config-ldflags.py
index 0854698..f397a7c 100644
--- a/admin/python-config-ldflags.py
+++ b/admin/python-config-ldflags.py
@@ -1,38 +1,70 @@
-#!/usr/bin/env python
+# This scripts retrieves the proper options to be used to link against
+# the libpython, in a machine-independant way. It invokes the official
+# script python-config (which thankfully deals with all the details).
-# DUPLICATE of "python-config --ldflags", fixed for the library location
+import sys
+newerpython = (sys.version_info[0] == 3 and sys.version_info[1] > 7)
-# This utility is known to work with:
-# python2.6 (system install) under SL6.4
-# python2.7 (custom install) under SL6.4
-# python3.4 (custom install) under SL6.4
-# python2.7 (system install) under Fedora20
-# python2.7 (Apple install) under MacOSX
-# python2.7 (MacPorts install) under MacOSX
-# python3.4 (MacPorts install) under MacOSX
+if newerpython:
+ # From now on avoid duplicating python-config, which evolves on its own.
+ # Invoke 'python-config --ldflags --embed'. The embed option (under
+ # Python 3) adds the libpython itself, whose name is highly
+ # unpredictible under the variety of machines and configurations we
+ # support
+ import subprocess
+ output = subprocess.check_output(['python-config', '--ldflags','--embed'])
+ output = output.decode('utf-8')
+ #print(output)
-import sys
-import sysconfig
+ args = output.split()
-pyver = sysconfig.get_config_var('VERSION')
-getvar = sysconfig.get_config_var
+ output = ''
+ for arg in args:
+ # Discard /usr/lib* path which causes troubles on the link command
+ # line, as it basically overrides all other custom paths coming after
+ # it. No need to put these paths on command line, they are found
+ # implicitly by the linker.
+ if arg not in ['-L/usr/lib','-L/usr/lib32','-L/usr/lib64']:
+ output += arg+' '
+
+ print(output)
-libs = getvar('LIBS').split() + getvar('SYSLIBS').split()
-if (hasattr(sys,'abiflags')):
- libs.append('-lpython' + pyver + sys.abiflags)
else:
- libs.append('-lpython' + pyver)
+ # DUPLICATE of "python-config --ldflags", fixed for the library location
+ # This proved to work gracefully up to Python 3.5 (exact limit unclear)
+
+ # This utility is known to work with:
+ # python2.6 (system install) under SL6.4
+ # python2.7 (custom install) under SL6.4
+ # python3.4 (custom install) under SL6.4
+ # python3.7 (custom install) under Debian12
+ # python2.7 (system install) under Fedora20
+ # python2.7 (Apple install) under MacOSX
+ # python2.7 (MacPorts install) under MacOSX
+ # python3.4 (MacPorts install) under MacOSX
+
+ import sys
+ import sysconfig
+
+ pyver = sysconfig.get_config_var('VERSION')
+ getvar = sysconfig.get_config_var
+
+ libs = getvar('LIBS').split() + getvar('SYSLIBS').split()
+ if (hasattr(sys,'abiflags')):
+ libs.append('-lpython' + pyver + sys.abiflags)
+ else:
+ libs.append('-lpython' + pyver)
-# Add the library path, except /usr/lib* which causes troubles
-# on the link command line, as it basically overrides all other
-# custom paths coming after it. No need to put these paths on
-# command line, they are found implicitly by the linker.
-ldpath = getvar('LIBDIR')
-if ldpath not in ['/usr/lib','/usr/lib32','/usr/lib64']:
- libs.insert(0, '-L' + getvar('LIBDIR'))
+ # Add the library path, except /usr/lib* which causes troubles
+ # on the link command line, as it basically overrides all other
+ # custom paths coming after it. No need to put these paths on
+ # command line, they are found implicitly by the linker.
+ ldpath = getvar('LIBDIR')
+ if ldpath not in ['/usr/lib','/usr/lib32','/usr/lib64']:
+ libs.insert(0, '-L' + getvar('LIBDIR'))
-# Framework (specific for Mac)
-if not getvar('PYTHONFRAMEWORK'):
- libs.extend(getvar('LINKFORSHARED').split())
+ # Framework (specific for Mac)
+ if not getvar('PYTHONFRAMEWORK'):
+ libs.extend(getvar('LINKFORSHARED').split())
-print(' '.join(libs))
+ print(' '.join(libs))
+58
View File
@@ -31,6 +31,7 @@
perl,
pixman,
vips,
buildPackages,
sourcesJSON ? ./sources.json,
}:
let
@@ -38,6 +39,62 @@ let
sources = lib.importJSON sourcesJSON;
inherit (sources) version;
esbuild_0_23 = buildPackages.esbuild.override {
buildGoModule =
args:
buildPackages.buildGoModule (
args
// rec {
version = "0.23.0";
src = fetchFromGitHub {
owner = "evanw";
repo = "esbuild";
tag = "v${version}";
hash = "sha256-AH4Y5ELPicAdJZY5CBf2byOxTzOyQFRh4XoqRUQiAQw=";
};
vendorHash = "sha256-+BfxCyg0KkDQpHt/wycy/8CTG6YBA/VJvJFhhzUnSiQ=";
}
);
};
esbuild_0_25 = buildPackages.esbuild.override {
buildGoModule =
args:
buildPackages.buildGoModule (
args
// rec {
version = "0.25.2";
src = fetchFromGitHub {
owner = "evanw";
repo = "esbuild";
tag = "v${version}";
hash = "sha256-aDxheDMeQYqCT9XO3In6RbmzmXVchn+bjgf3nL3VE4I=";
};
vendorHash = "sha256-+BfxCyg0KkDQpHt/wycy/8CTG6YBA/VJvJFhhzUnSiQ=";
}
);
};
# Immich server does not actually need esbuild, but react-email and vite do.
# As esbuild doesn't support passing multiple binaries, we use a custom
# "shim", that picks the right version depending on the working directory.
# The correct version can be looked up in package-lock.json
# TODO: There are numerous other env vars this *could* be based on.
esbuildShim = buildPackages.writeShellScriptBin "esbuild" ''
echo "nixpkgs: esbuild shim for '$PWD'" >&2
case "$PWD" in
"/build/server/node_modules/esbuild")
exec ${lib.getExe esbuild_0_23} "$@"
;;
"/build/server/node_modules/vite/node_modules/esbuild")
exec ${lib.getExe esbuild_0_25} "$@"
exit 0
;;
esac
echo "nixpkgs: Couldn't resolve esbuild version for '$PWD'" >&2
exit 1
'';
buildLock = {
sources =
builtins.map
@@ -206,6 +263,7 @@ buildNpmPackage' {
makeCacheWritable = true;
env.SHARP_FORCE_GLOBAL_LIBVIPS = 1;
env.ESBUILD_BINARY_PATH = lib.getExe esbuildShim;
preBuild = ''
# If exiftool-vendored.pl isn't found, exiftool is searched for on the PATH
@@ -1,15 +1,15 @@
{
"version": "3.2.13",
"version": "3.3.12",
"x86_64-linux": {
"url": "https://github.com/laurent22/joplin/releases/download/v3.2.13/Joplin-3.2.13.AppImage",
"sha256": "06xmm2annf3i8qfi8hclac3lgfssb2f3sx06vgabgsn67i8gid20"
"url": "https://github.com/laurent22/joplin/releases/download/v3.3.12/Joplin-3.3.12.AppImage",
"sha256": "1fjrblmlpm6sf4jdvifmyxic0rw2bs1f4sbw3nz4xy7wlsab5f62"
},
"x86_64-darwin": {
"url": "https://github.com/laurent22/joplin/releases/download/v3.2.13/Joplin-3.2.13.dmg",
"sha256": "1z9lp07z85jf1g2rwzn4q5kssfqqb921lfqgkjkjnz12padf3kpf"
"url": "https://github.com/laurent22/joplin/releases/download/v3.3.12/Joplin-3.3.12.dmg",
"sha256": "0rk5jl7i7sj31336r8yn8wf9h4xwdwi66wvwrkblvxrfhgddn2gj"
},
"aarch64-darwin": {
"url": "https://github.com/laurent22/joplin/releases/download/v3.2.13/Joplin-3.2.13-arm64.dmg",
"sha256": "0r7rfka60vrynwxdfk71mbhdwxv2rivxqc2qpzrhmz26h8vksm3h"
"url": "https://github.com/laurent22/joplin/releases/download/v3.3.12/Joplin-3.3.12-arm64.dmg",
"sha256": "13m4nypg1v5d7i13has9f1sp08dijc44962dr75b9jfiq8q6ciz6"
}
}
+1
View File
@@ -62,5 +62,6 @@ stdenv.mkDerivation rec {
"sparc64-linux"
];
license = licenses.gpl2Only;
mainProgram = "kexec";
};
}
+2 -2
View File
@@ -9,11 +9,11 @@
stdenvNoCC.mkDerivation rec {
pname = "komga";
version = "1.21.2";
version = "1.21.3";
src = fetchurl {
url = "https://github.com/gotson/${pname}/releases/download/${version}/${pname}-${version}.jar";
sha256 = "sha256-FYw519VT40PU3fVEb7DBoST2bqhPXcEqquHkGeULQ3k=";
sha256 = "sha256-NFj/C1oNRh9PzAi5TUv+4vVea1Nsn/frxf4aZjuYfvA=";
};
nativeBuildInputs = [
+2 -2
View File
@@ -8,12 +8,12 @@
python3Packages.buildPythonApplication rec {
pname = "latexminted";
version = "0.5.1";
version = "0.6.0";
pyproject = true;
src = fetchPypi {
inherit pname version;
hash = "sha256-II3n7DtgTyuE2PMygJrmRW8uBRpnnoz2NXDMw20o8oo=";
hash = "sha256-WpYo9Ci3rshuVdsbAv4Hjx8vT2FLRinhNsVrcGoPXyU=";
};
build-system = with python3Packages; [
+2 -3
View File
@@ -174,11 +174,11 @@ in
stdenv.mkDerivation (finalAttrs: {
pname = "microsoft-edge";
version = "135.0.3179.85";
version = "136.0.3240.76";
src = fetchurl {
url = "https://packages.microsoft.com/repos/edge/pool/main/m/microsoft-edge-stable/microsoft-edge-stable_${finalAttrs.version}-1_amd64.deb";
hash = "sha256-x1YpKsvj2Jx1/VE13eE/aCkv+b7rGOQo4xcRYu2GQGA=";
hash = "sha256-biNM1exJ/xUcmhZjH7ZcFF9cYVqsPavbbtsJnRVlyFo=";
};
# With strictDeps on, some shebangs were not being patched correctly
@@ -284,7 +284,6 @@ stdenv.mkDerivation (finalAttrs: {
license = lib.licenses.unfree;
mainProgram = "microsoft-edge";
maintainers = with lib.maintainers; [
zanculmarktum
kuwii
rhysmdnz
];
+43
View File
@@ -0,0 +1,43 @@
{
lib,
rustPlatform,
fetchCrate,
pkg-config,
openssl,
versionCheckHook,
}:
rustPlatform.buildRustPackage (finalAttrs: {
pname = "mini-redis";
version = "0.4.1";
src = fetchCrate {
inherit (finalAttrs) pname version;
sha256 = "sha256-vYphaQNMAHajod5oT/T3VJ12e6Qk5QOa5LQz6KsXvm8=";
};
cargoHash = "sha256-oGyJxNzJX7PwMkDoT9Tb3xF0vWgQwuyIjKPgEkbPKyI=";
nativeBuildInputs = [
pkg-config
];
buildInputs = [
openssl
];
nativeInstallCheckInputs = [
versionCheckHook
];
doInstallCheck = true;
versionCheckProgram = "${placeholder "out"}/bin/${finalAttrs.meta.mainProgram}";
doCheck = false;
meta = {
description = "Incomplete, idiomatic implementation of a Redis client and server built with Tokio, for learning purposes";
homepage = "https://github.com/tokio-rs/mini-redis";
license = lib.licenses.mit;
maintainers = with lib.maintainers; [ nomaterials ];
mainProgram = "mini-redis-cli";
};
})
+2 -2
View File
@@ -11,13 +11,13 @@
stdenv.mkDerivation (finalAttrs: {
pname = "msolve";
version = "0.7.5";
version = "0.8.0";
src = fetchFromGitHub {
owner = "algebraic-solving";
repo = "msolve";
tag = "v${finalAttrs.version}";
hash = "sha256-3AP3qrFZX2JZveONtmG0CLpdwSCwlrW86D8QLRTW5kI=";
hash = "sha256-0kqRnBJA5CwsLY/YWZXu2+y4aiZAQQYl30Qb3JX3zEo=";
};
postPatch = ''
+2 -2
View File
@@ -11,13 +11,13 @@
stdenv.mkDerivation rec {
pname = "nb";
version = "7.17.0";
version = "7.18.1";
src = fetchFromGitHub {
owner = "xwmx";
repo = "nb";
rev = version;
hash = "sha256-gUI7hAZabYPHkSwGtFZxEoi5Hw76fOLYbMZQIvsnSas=";
hash = "sha256-SKn4/Nqmvv8kRQkooGrvTuVrj70rastVg4j7U3cXdYg=";
};
nativeBuildInputs = [ installShellFiles ];
+3 -3
View File
@@ -6,16 +6,16 @@
buildGoModule (finalAttrs: {
pname = "opencode";
version = "0.0.34";
version = "0.0.46";
src = fetchFromGitHub {
owner = "opencode-ai";
repo = "opencode";
tag = "v${finalAttrs.version}";
hash = "sha256-EaspkL0TEBJEUU3f75EhZ4BOIvbneUKnTNeNGhJdjYE=";
hash = "sha256-Q7ArUsFMpe0zayUMBJd+fC1K4jTGElIFep31Qa/L1jY=";
};
vendorHash = "sha256-cFzkMunPkGQDFhQ4NQZixc5z7JCGNI7eXBn826rWEvk=";
vendorHash = "sha256-MVpluFTF/2S6tRQQAXE3ujskQZ3njBkfve0RQgk3IkQ=";
checkFlags =
let
+3 -3
View File
@@ -7,13 +7,13 @@
buildGoModule rec {
pname = "orchard";
version = "0.33.0";
version = "0.33.2";
src = fetchFromGitHub {
owner = "cirruslabs";
repo = pname;
rev = version;
hash = "sha256-cOg7wwcwmpDNqnu15j5aYxLNpBxrhliK6w3sw2JQlCg=";
hash = "sha256-yiCMnP73C5MJLYjnZfqcKtdSzPyL/9WlAtylMXDl4E8=";
# populate values that require us to use git. By doing this in postFetch we
# can delete .git afterwards and maintain better reproducibility of the src.
leaveDotGit = true;
@@ -24,7 +24,7 @@ buildGoModule rec {
'';
};
vendorHash = "sha256-60GjN9jeYjGdkVxm+lNBS0OYt523c/HrfBPrvdET0hQ=";
vendorHash = "sha256-fU2TXUtcXmjswlEbSsbCTOaC5rvtctHbTKbR7zIwP/g=";
nativeBuildInputs = [ installShellFiles ];
+3 -3
View File
@@ -7,16 +7,16 @@
buildGoModule rec {
pname = "pocketbase";
version = "0.27.2";
version = "0.28.1";
src = fetchFromGitHub {
owner = "pocketbase";
repo = "pocketbase";
rev = "v${version}";
hash = "sha256-KvKBx5AKpcvgdf8tq2sJPLF63Fpa9KN3j5WJumR28k4=";
hash = "sha256-tx9dx4ZFmdllG/pMoI8mmPSvMg7fBk6+lXSxkW5jlDM=";
};
vendorHash = "sha256-1Qym5XRyMBfn5csp+YFkKNhJokDrHbfnpKAMq09Da5s=";
vendorHash = "sha256-DN3rCuRBFVeRfiXrwxeHemqOZgXb7OswwzcEqHbi4lo=";
# This is the released subpackage from upstream repo
subPackages = [ "examples/base" ];
+3 -3
View File
@@ -10,17 +10,17 @@
rustPlatform.buildRustPackage rec {
pname = "proto";
version = "0.48.1";
version = "0.49.1";
src = fetchFromGitHub {
owner = "moonrepo";
repo = "proto";
rev = "v${version}";
hash = "sha256-4ikjpr1IRULLpWC8sseWuF20YXUuCfdCP6VU/VgGWzE=";
hash = "sha256-VtU59YvNqpHvZ1WRj87Heo8RDyCOzleB+odE4DOQYag=";
};
useFetchCargoVendor = true;
cargoHash = "sha256-aa4fL33B4kAZx7A6XRvwLlUHsyZve5WOZBnGCWtfqFU=";
cargoHash = "sha256-wPB4YBNzDg9eoVCY4bbbvKu171Qdh7JJZIT9rD5hVdI=";
buildInputs = lib.optionals stdenv.hostPlatform.isDarwin [
libiconv
-1
View File
@@ -72,7 +72,6 @@ rustPlatform.buildRustPackage {
];
maintainers = with lib.maintainers; [
detroyejr
uncenter
];
};
}
+2 -2
View File
@@ -8,11 +8,11 @@
stdenv.mkDerivation (finalAttrs: {
pname = "quarkus-cli";
version = "3.21.4";
version = "3.22.2";
src = fetchurl {
url = "https://github.com/quarkusio/quarkus/releases/download/${finalAttrs.version}/quarkus-cli-${finalAttrs.version}.tar.gz";
hash = "sha256-ksI55x1rmpIRfNNgajmAvprKU3OwL4EW8QpNV2eyPTc=";
hash = "sha256-RCWkaPoE3Purq9VG1xhlakMxqXhnxi+q10YcgOyScqg=";
};
nativeBuildInputs = [ makeWrapper ];
+5 -2
View File
@@ -23,15 +23,16 @@
pango,
util-linux,
xz,
nix-update-script,
}:
stdenv.mkDerivation (finalAttrs: {
pname = "reqable";
version = "2.33.8";
version = "2.33.12";
src = fetchurl {
url = "https://github.com/reqable/reqable-app/releases/download/${finalAttrs.version}/reqable-app-linux-x86_64.deb";
hash = "sha256-YCuJpTDJNAHBhTrxl5qvtFnUm4VzhkJ66gaKHhWVBEU=";
hash = "sha256-LCHeJUzTRjl/lh3PWygZV0Rd3AxJEGlTkVrI/5l+Go4=";
};
nativeBuildInputs = [
@@ -77,6 +78,8 @@ stdenv.mkDerivation (finalAttrs: {
--prefix LD_LIBRARY_PATH : $out/share/reqable/lib
'';
passthru.updateScript = nix-update-script { };
meta = {
description = "Generation API debugging and testing one-stop solution";
homepage = "https://reqable.com";
+2 -2
View File
@@ -16,7 +16,7 @@
stdenv,
}:
let
version = "2.49.1525";
version = "2.51.1534";
urlVersion = builtins.replaceStrings [ "." ] [ "0" ] version;
in
stdenv.mkDerivation {
@@ -25,7 +25,7 @@ stdenv.mkDerivation {
src = fetchurl {
url = "https://download.roonlabs.com/updates/production/RoonServer_linuxx64_${urlVersion}.tar.bz2";
hash = "sha256-DYxybP7luRmR4HL6QYBeWU4ZWqlHEO2EgLeqxmFD87A=";
hash = "sha256-x9zbWJ4lrqfC1CPquGsdgzhO3WBzd46dlZy6APqJbcg=";
};
dontConfigure = true;
+32 -24
View File
@@ -69,37 +69,45 @@ rustPlatform.buildRustPackage rec {
useFetchCargoVendor = true;
cargoRoot = "app/${app-type}/src-tauri";
buildAndTestSubdir = cargoRoot;
cargoPatches = [ ./remove-duplicate-versions-of-sys-metrics.patch ];
cargoPatches = [
./remove-duplicate-versions-of-sys-metrics.patch
./remove-code-signing-darwin.patch
];
cargoHash = app-type-either "sha256-XfN+/oC3lttDquLfoyJWBaFfdjW/wyODCIiZZksypLM=" "sha256-4vBHxuKg4P9H0FZYYNUT+AVj4Qvz99q7Bhd7x47UC2w=";
nativeBuildInputs = [
proper-cargo-tauri.hook
nativeBuildInputs =
[
proper-cargo-tauri.hook
# Setup pnpm
nodejs
pnpm_9.configHook
# Setup pnpm
nodejs
pnpm_9.configHook
# Make sure we can find our libraries
perl
pkg-config
protobuf
wrapGAppsHook4
];
# Make sure we can find our libraries
perl
pkg-config
protobuf
]
++ lib.optionals stdenv.hostPlatform.isLinux [
wrapGAppsHook4
];
buildInputs =
[ openssl ]
++ lib.optionals stdenv.hostPlatform.isLinux [
glib-networking
libayatana-appindicator
]
++ lib.optionals (app-type == "main") [
webkitgtk_4_1
libsoup_3
]
++ lib.optionals (app-type == "legacy") [
webkitgtk_4_0
libsoup_2_4
];
++ lib.optionals stdenv.hostPlatform.isLinux (
[
glib-networking
libayatana-appindicator
]
++ lib.optionals (app-type == "main") [
webkitgtk_4_1
libsoup_3
]
++ lib.optionals (app-type == "legacy") [
webkitgtk_4_0
libsoup_2_4
]
);
passthru =
# Don't set an update script for the legacy version
@@ -0,0 +1,12 @@